.tox {
    box-shadow: none;
    box-sizing: content-box;
    color: var(--bs-body-bg);
    cursor: auto;
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
    font-size: 16px;
    font-style: normal;
    font-weight: 400;
    line-height: normal;
    -webkit-tap-highlight-color: transparent;
    -webkit-text-decoration: none;
    text-decoration: none;
    text-shadow: none;
    text-transform: none;
    vertical-align: initial;
    white-space: normal
}

[data-bs-theme="dark"] .tox :not(svg):not(rect) {
    box-sizing: inherit;
    color: inherit;
    cursor: inherit;
    direction: inherit;
    font-family: inherit;
    font-size: inherit;
    font-style: inherit;
    font-weight: inherit;
    line-height: inherit;
    -webkit-tap-highlight-color: inherit;
    text-align: inherit;
    text-decoration: inherit;
    text-shadow: inherit;
    text-transform: inherit;
    vertical-align: inherit;
    white-space: inherit
}

[data-bs-theme="dark"] .tox :not(svg):not(rect) {
    background: 0 0;
    border: 0;
    box-shadow: none;
    float: none;
    height: auto;
    margin: 0;
    max-width: none;
    outline: 0;
    padding: 0;
    position: static;
    width: auto
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) {
    direction: ltr;
    text-align: left
}

[data-bs-theme="dark"] .tox[dir=rtl] {
    direction: rtl;
    text-align: right
}

[data-bs-theme="dark"] .tox-tinymce {
    border: 2px solid #161f29;
    border-radius: 10px;
    box-shadow: none;
    box-sizing: border-box;
    display: flex;
    flex-direction: column;
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
    overflow: hidden;
    position: relative;
    visibility: inherit !important
}

[data-bs-theme="dark"] .tox.tox-tinymce-inline {
    border: none;
    box-shadow: none;
    overflow: initial
}

[data-bs-theme="dark"] .tox.tox-tinymce-inline .tox-editor-container {
    overflow: initial
}

[data-bs-theme="dark"] .tox.tox-tinymce-inline .tox-editor-header {
    background-color: var(--bs-body-bg);
    border: 2px solid #161f29;
    border-radius: 10px;
    box-shadow: none;
    overflow: hidden
}

[data-bs-theme="dark"] .tox-tinymce-aux {
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
    z-index: 1300
}

[data-bs-theme="dark"] .tox-tinymce :focus,
[data-bs-theme="dark"] .tox-tinymce-aux :focus {
    outline: 0
}

button::-moz-focus-inner {
    border: 0
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-icon--flip svg {
    transform: rotateY(180deg)
}

[data-bs-theme="dark"] .tox .accessibility-issue__header {
    align-items: center;
    display: flex;
    margin-bottom: 4px
}

[data-bs-theme="dark"] .tox .accessibility-issue__description {
    align-items: stretch;
    border-radius: 6px;
    display: flex;
    justify-content: space-between
}

[data-bs-theme="dark"] .tox .accessibility-issue__description > div {
    padding-bottom: 4px
}

[data-bs-theme="dark"] .tox .accessibility-issue__description > div > div {
    align-items: center;
    display: flex;
    margin-bottom: 4px
}

[data-bs-theme="dark"] .tox .accessibility-issue__description > div > div .tox-icon svg {
    display: block
}

[data-bs-theme="dark"] .tox .accessibility-issue__repair {
    margin-top: 16px
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--info .accessibility-issue__description {
    background-color: rgba(0, 101, 216, .4);
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--info .tox-form__group h2 {
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--info .tox-icon svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--info a.tox-button--naked.tox-button--icon {
    background-color: #006ce7;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--info a.tox-button--naked.tox-button--icon:focus,
[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--info a.tox-button--naked.tox-button--icon:hover {
    background-color: #0060ce
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--info a.tox-button--naked.tox-button--icon:active {
    background-color: #0054b4
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--warn .accessibility-issue__description {
    background-color: rgba(255, 165, 0, .5);
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--warn .tox-form__group h2 {
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--warn .tox-icon svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--warn a.tox-button--naked.tox-button--icon {
    background-color: #ffe89d;
    color: var(--bs-body-bg)
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--warn a.tox-button--naked.tox-button--icon:focus,
[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--warn a.tox-button--naked.tox-button--icon:hover {
    background-color: #f2d574;
    color: var(--bs-body-bg)
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--warn a.tox-button--naked.tox-button--icon:active {
    background-color: #e8c657;
    color: var(--bs-body-bg)
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--error .accessibility-issue__description {
    background-color: rgba(204, 0, 0, .5);
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--error .tox-form__group h2 {
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--error .tox-icon svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--error a.tox-button--naked.tox-button--icon {
    background-color: #f2bfbf;
    color: var(--bs-body-bg)
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--error a.tox-button--naked.tox-button--icon:focus,
[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--error a.tox-button--naked.tox-button--icon:hover {
    background-color: #e9a4a4;
    color: var(--bs-body-bg)
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--error a.tox-button--naked.tox-button--icon:active {
    background-color: #ee9494;
    color: var(--bs-body-bg)
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--success .accessibility-issue__description {
    background-color: rgba(120, 171, 70, .5);
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--success .accessibility-issue__description > :last-child {
    display: none
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--success .tox-form__group h2 {
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue--success .tox-icon svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .accessibility-issue__header .tox-form__group h1,
[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group .accessibility-issue__description h2 {
    font-size: 14px;
    margin-top: 0
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-dialog__body-content .accessibility-issue__header .tox-button {
    margin-left: 4px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-dialog__body-content .accessibility-issue__header > :nth-last-child(2) {
    margin-left: auto
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-dialog__body-content .accessibility-issue__description {
    padding: 4px 4px 4px 8px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-dialog__body-content .accessibility-issue__header .tox-button {
    margin-right: 4px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-dialog__body-content .accessibility-issue__header > :nth-last-child(2) {
    margin-right: auto
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-dialog__body-content .accessibility-issue__description {
    padding: 4px 8px 4px 4px
}

[data-bs-theme="dark"] .tox .mce-codemirror {
    background: #fff;
    bottom: 0;
    font-size: 13px;
    left: 0;
    position: absolute;
    right: 0;
    top: 0;
    z-index: 1
}

[data-bs-theme="dark"] .tox .mce-codemirror.tox-inline-codemirror {
    margin: 8px;
    position: absolute
}

[data-bs-theme="dark"] .tox .tox-advtemplate .tox-form__grid {
    flex: 1
}

[data-bs-theme="dark"] .tox .tox-advtemplate .tox-form__grid > div:first-child {
    display: flex;
    flex-direction: column;
    width: 30%
}

[data-bs-theme="dark"] .tox .tox-advtemplate .tox-form__grid > div:first-child > div:nth-child(2) {
    flex-basis: 0;
    flex-grow: 1;
    overflow: auto
}

@media only screen and (max-width: 767px) {
    body:not(.tox-force-desktop) .tox .tox-advtemplate .tox-form__grid > div:first-child {
        width: 100%
    }
}

[data-bs-theme="dark"] .tox .tox-advtemplate iframe {
    border-color: #161f29;
    border-radius: 10px;
    border-style: solid;
    border-width: 1px;
    margin: 0 10px
}

[data-bs-theme="dark"] .tox .tox-anchorbar {
    display: flex;
    flex: 0 0 auto
}

[data-bs-theme="dark"] .tox .tox-bottom-anchorbar {
    display: flex;
    flex: 0 0 auto
}

[data-bs-theme="dark"] .tox .tox-bar {
    display: flex;
    flex: 0 0 auto
}

[data-bs-theme="dark"] .tox .tox-button {
    background-color: #006ce7;
    background-image: none;
    background-position: 0 0;
    background-repeat: repeat;
    border-color: #006ce7;
    border-radius: 6px;
    border-style: solid;
    border-width: 1px;
    box-shadow: none;
    box-sizing: border-box;
    color: #fff;
    cursor: pointer;
    display: inline-block;
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
    font-size: 14px;
    font-style: normal;
    font-weight: 700;
    letter-spacing: normal;
    line-height: 24px;
    margin: 0;
    outline: 0;
    padding: 4px 16px;
    position: relative;
    text-align: center;
    -webkit-text-decoration: none;
    text-decoration: none;
    text-transform: none;
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-button::before {
    border-radius: 6px;
    bottom: -1px;
    box-shadow: inset 0 0 0 1px #fff, 0 0 0 2px #006ce7;
    content: '';
    left: -1px;
    opacity: 0;
    pointer-events: none;
    position: absolute;
    right: -1px;
    top: -1px
}

[data-bs-theme="dark"] .tox .tox-button[disabled] {
    background-color: #006ce7;
    background-image: none;
    border-color: #006ce7;
    box-shadow: none;
    color: rgba(255, 255, 255, .5);
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-button:focus:not(:disabled) {
    background-color: #0060ce;
    background-image: none;
    border-color: #0060ce;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button:focus:not(:disabled)::before {
    opacity: 1
}

[data-bs-theme="dark"] .tox .tox-button:hover:not(:disabled) {
    background-color: #0060ce;
    background-image: none;
    border-color: #0060ce;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button:active:not(:disabled) {
    background-color: #0054b4;
    background-image: none;
    border-color: #0054b4;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button.tox-button--enabled {
    background-color: #0054b4;
    background-image: none;
    border-color: #0054b4;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button.tox-button--enabled[disabled] {
    background-color: #0054b4;
    background-image: none;
    border-color: #0054b4;
    box-shadow: none;
    color: rgba(255, 255, 255, .5);
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-button.tox-button--enabled:focus:not(:disabled) {
    background-color: #00489b;
    background-image: none;
    border-color: #00489b;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button.tox-button--enabled:hover:not(:disabled) {
    background-color: #00489b;
    background-image: none;
    border-color: #00489b;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button.tox-button--enabled:active:not(:disabled) {
    background-color: #003c81;
    background-image: none;
    border-color: #003c81;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button--icon-and-text,
[data-bs-theme="dark"] .tox .tox-button.tox-button--icon-and-text,
[data-bs-theme="dark"] .tox .tox-button.tox-button--secondary.tox-button--icon-and-text {
    display: flex;
    padding: 5px 4px
}

[data-bs-theme="dark"] .tox .tox-button--icon-and-text .tox-icon svg,
[data-bs-theme="dark"] .tox .tox-button.tox-button--icon-and-text .tox-icon svg,
[data-bs-theme="dark"] .tox .tox-button.tox-button--secondary.tox-button--icon-and-text .tox-icon svg {
    display: block;
    fill: currentColor
}

[data-bs-theme="dark"] .tox .tox-button--secondary {
    background-color: #3d546f;
    background-image: none;
    background-position: 0 0;
    background-repeat: repeat;
    border-color: #3d546f;
    border-radius: 6px;
    border-style: solid;
    border-width: 1px;
    box-shadow: none;
    color: #fff;
    font-size: 14px;
    font-style: normal;
    font-weight: 700;
    letter-spacing: normal;
    outline: 0;
    padding: 4px 16px;
    -webkit-text-decoration: none;
    text-decoration: none;
    text-transform: none
}

[data-bs-theme="dark"] .tox .tox-button--secondary[disabled] {
    background-color: #3d546f;
    background-image: none;
    border-color: #3d546f;
    box-shadow: none;
    color: rgba(255, 255, 255, .5)
}

[data-bs-theme="dark"] .tox .tox-button--secondary:focus:not(:disabled) {
    background-color: #34485f;
    background-image: none;
    border-color: #34485f;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button--secondary:hover:not(:disabled) {
    background-color: #34485f;
    background-image: none;
    border-color: #34485f;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button--secondary:active:not(:disabled) {
    background-color: #2b3b4e;
    background-image: none;
    border-color: #2b3b4e;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button--secondary.tox-button--enabled {
    background-color: #2b5c93;
    background-image: none;
    border-color: #2b5c93;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button--secondary.tox-button--enabled[disabled] {
    background-color: #2b5c93;
    background-image: none;
    border-color: #2b5c93;
    box-shadow: none;
    color: rgba(255, 255, 255, .5)
}

[data-bs-theme="dark"] .tox .tox-button--secondary.tox-button--enabled:focus:not(:disabled) {
    background-color: #254f80;
    background-image: none;
    border-color: #254f80;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button--secondary.tox-button--enabled:hover:not(:disabled) {
    background-color: #254f80;
    background-image: none;
    border-color: #254f80;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button--secondary.tox-button--enabled:active:not(:disabled) {
    background-color: #1f436c;
    background-image: none;
    border-color: #1f436c;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button--icon,
[data-bs-theme="dark"] .tox .tox-button.tox-button--icon,
[data-bs-theme="dark"] .tox .tox-button.tox-button--secondary.tox-button--icon {
    padding: 4px
}

[data-bs-theme="dark"] .tox .tox-button--icon .tox-icon svg,
[data-bs-theme="dark"] .tox .tox-button.tox-button--icon .tox-icon svg,
[data-bs-theme="dark"] .tox .tox-button.tox-button--secondary.tox-button--icon .tox-icon svg {
    display: block;
    fill: currentColor
}

[data-bs-theme="dark"] .tox .tox-button-link {
    background: 0;
    border: none;
    box-sizing: border-box;
    cursor: pointer;
    display: inline-block;
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
    font-size: 16px;
    font-weight: 400;
    line-height: 1.3;
    margin: 0;
    padding: 0;
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-button-link--sm {
    font-size: 14px
}

[data-bs-theme="dark"] .tox .tox-button--naked {
    background-color: transparent;
    border-color: transparent;
    box-shadow: unset;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button--naked[disabled] {
    background-color: rgba(255, 255, 255, .2);
    border-color: transparent;
    box-shadow: unset;
    color: rgba(255, 255, 255, .5)
}

[data-bs-theme="dark"] .tox .tox-button--naked:hover:not(:disabled) {
    background-color: rgba(255, 255, 255, .2);
    border-color: transparent;
    box-shadow: unset;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button--naked:focus:not(:disabled) {
    background-color: rgba(255, 255, 255, .2);
    border-color: transparent;
    box-shadow: unset;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button--naked:active:not(:disabled) {
    background-color: rgba(255, 255, 255, .3);
    border-color: transparent;
    box-shadow: unset;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-button--naked .tox-icon svg {
    fill: currentColor
}

[data-bs-theme="dark"] .tox .tox-button--naked.tox-button--icon:hover:not(:disabled) {
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-checkbox {
    align-items: center;
    border-radius: 6px;
    cursor: pointer;
    display: flex;
    height: 36px;
    min-width: 36px
}

[data-bs-theme="dark"] .tox .tox-checkbox__input {
    height: 1px;
    overflow: hidden;
    position: absolute;
    top: auto;
    width: 1px
}

[data-bs-theme="dark"] .tox .tox-checkbox__icons {
    align-items: center;
    border-radius: 6px;
    box-shadow: 0 0 0 2px transparent;
    box-sizing: content-box;
    display: flex;
    height: 24px;
    justify-content: center;
    padding: calc(4px - 1px);
    width: 24px
}

[data-bs-theme="dark"] .tox .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
    display: block;
    fill: rgba(255, 255, 255, 0.2)
}

@media (forced-colors: active) {
    .tox .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
        fill: currentColor !important
    }
}

[data-bs-theme="dark"] .tox .tox-checkbox__icons .tox-checkbox-icon__indeterminate svg {
    display: none;
    fill: #006ce7
}

[data-bs-theme="dark"] .tox .tox-checkbox__icons .tox-checkbox-icon__checked svg {
    display: none;
    fill: #006ce7
}

[data-bs-theme="dark"] .tox .tox-checkbox--disabled {
    color: rgba(255, 255, 255, .5);
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-checkbox--disabled .tox-checkbox__icons .tox-checkbox-icon__checked svg {
    fill: rgba(255, 255, 255, 0.5)
}

[data-bs-theme="dark"] .tox .tox-checkbox--disabled .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
    fill: rgba(255, 255, 255, 0.5)
}

[data-bs-theme="dark"] .tox .tox-checkbox--disabled .tox-checkbox__icons .tox-checkbox-icon__indeterminate svg {
    fill: rgba(255, 255, 255, 0.5)
}

[data-bs-theme="dark"] .tox input.tox-checkbox__input:checked + .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
    display: none
}

[data-bs-theme="dark"] .tox input.tox-checkbox__input:checked + .tox-checkbox__icons .tox-checkbox-icon__checked svg {
    display: block
}

[data-bs-theme="dark"] .tox input.tox-checkbox__input:indeterminate + .tox-checkbox__icons .tox-checkbox-icon__unchecked svg {
    display: none
}

[data-bs-theme="dark"] .tox input.tox-checkbox__input:indeterminate + .tox-checkbox__icons .tox-checkbox-icon__indeterminate svg {
    display: block
}

[data-bs-theme="dark"] .tox input.tox-checkbox__input:focus + .tox-checkbox__icons {
    border-radius: 6px;
    box-shadow: inset 0 0 0 1px #006ce7;
    padding: calc(4px - 1px)
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-checkbox__label {
    margin-left: 4px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-checkbox__input {
    left: -10000px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-bar .tox-checkbox {
    margin-left: 4px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-checkbox__label {
    margin-right: 4px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-checkbox__input {
    right: -10000px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-bar .tox-checkbox {
    margin-right: 4px
}

[data-bs-theme="dark"] .tox .tox-collection--toolbar .tox-collection__group {
    display: flex;
    padding: 0
}

[data-bs-theme="dark"] .tox .tox-collection--grid .tox-collection__group {
    display: flex;
    flex-wrap: wrap;
    max-height: 208px;
    overflow-x: hidden;
    overflow-y: auto;
    padding: 0
}

[data-bs-theme="dark"] .tox .tox-collection--list .tox-collection__group {
    border-bottom-width: 0;
    border-color: rgba(255, 255, 255, .15);
    border-left-width: 0;
    border-right-width: 0;
    border-style: solid;
    border-top-width: 1px;
    padding: 4px 0
}

[data-bs-theme="dark"] .tox .tox-collection--list .tox-collection__group:first-child {
    border-top-width: 0
}

[data-bs-theme="dark"] .tox .tox-collection__group-heading {
    background-color: rgba(255, 255, 255, .15);
    color: rgba(255, 255, 255, .5);
    cursor: default;
    font-size: 12px;
    font-style: normal;
    font-weight: 400;
    margin-bottom: 4px;
    margin-top: -4px;
    padding: 4px 8px;
    text-transform: none;
    -webkit-touch-callout: none;
    -webkit-user-select: none;
    user-select: none
}

[data-bs-theme="dark"] .tox .tox-collection__item {
    align-items: center;
    border-radius: 3px;
    color: #fff;
    display: flex;
    -webkit-touch-callout: none;
    -webkit-user-select: none;
    user-select: none
}

[data-bs-theme="dark"] .tox .tox-collection--list .tox-collection__item {
    padding: 4px 8px
}

[data-bs-theme="dark"] .tox .tox-collection--toolbar .tox-collection__item {
    border-radius: 3px;
    padding: 4px
}

[data-bs-theme="dark"] .tox .tox-collection--grid .tox-collection__item {
    border-radius: 3px;
    padding: 4px
}

[data-bs-theme="dark"] .tox .tox-collection--list .tox-collection__item--enabled:not(.tox-collection__item--state-disabled) {
    background-color: #2b3b4e;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-collection--list .tox-collection__item--active:not(.tox-collection__item--state-disabled) {
    background-color: #006ce7;
    color: #fff
}

@media (forced-colors: active) {
    .tox .tox-collection--list .tox-collection__item--active:not(.tox-collection__item--state-disabled) {
        border: solid 1px
    }
}

[data-bs-theme="dark"] .tox .tox-collection--grid .tox-collection__item--enabled:not(.tox-collection__item--state-disabled) {
    background-color: #599fef;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-collection--grid .tox-collection__item--active:not(.tox-collection__item--state-disabled) {
    background-color: #41474f;
    color: #fff;
    position: relative;
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-collection--grid .tox-collection__item--active:not(.tox-collection__item--state-disabled):focus::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff inset;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

@media (forced-colors: active) {
    .tox .tox-collection--grid .tox-collection__item--active:not(.tox-collection__item--state-disabled):focus::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-collection--toolbar .tox-collection__item--enabled:not(.tox-collection__item--state-disabled) {
    background-color: #599fef;
    color: #fff
}

@media (forced-colors: active) {
    .tox .tox-collection--toolbar .tox-collection__item--enabled:not(.tox-collection__item--state-disabled) {
        border-radius: 3px;
        outline: solid 1px
    }
}

[data-bs-theme="dark"] .tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled) {
    color: #fff;
    background-color: #2b3b4e;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled):hover {
    background-color: #41474f;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled):focus {
    background-color: #41474f;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled):focus::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

@media (forced-colors: active) {
    .tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled):focus::after {
        border: 2px solid highlight
    }
}

@media (forced-colors: active) {
    .tox .tox-collection--toolbar .tox-collection__item--active:not(.tox-collection__item--state-disabled):hover {
        border-radius: 3px;
        outline: solid 1px
    }
}

[data-bs-theme="dark"] .tox .tox-collection__item-checkmark,
[data-bs-theme="dark"] .tox .tox-collection__item-icon {
    align-items: center;
    display: flex;
    height: 24px;
    justify-content: center;
    width: 24px
}

[data-bs-theme="dark"] .tox .tox-collection__item-checkmark svg,
[data-bs-theme="dark"] .tox .tox-collection__item-icon svg {
    fill: currentColor
}

[data-bs-theme="dark"] .tox .tox-collection--toolbar-lg .tox-collection__item-icon {
    height: 48px;
    width: 48px
}

[data-bs-theme="dark"] .tox .tox-collection__item-label {
    color: currentColor;
    display: inline-block;
    flex: 1;
    font-size: 14px;
    font-style: normal;
    font-weight: 400;
    line-height: 24px;
    max-width: 100%;
    text-transform: none;
    word-break: break-all
}

[data-bs-theme="dark"] .tox .tox-collection__item-accessory {
    color: currentColor;
    display: inline-block;
    font-size: 14px;
    height: 24px;
    line-height: 24px;
    text-transform: none
}

[data-bs-theme="dark"] .tox .tox-collection__item-caret {
    align-items: center;
    display: flex;
    min-height: 24px
}

[data-bs-theme="dark"] .tox .tox-collection__item-caret::after {
    content: '';
    font-size: 0;
    min-height: inherit
}

[data-bs-theme="dark"] .tox .tox-collection__item-caret svg {
    fill: currentColor
}

[data-bs-theme="dark"] .tox .tox-collection__item--state-disabled {
    background-color: transparent;
    color: rgba(255, 255, 255, .5);
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-collection__item--state-disabled .tox-collection__item-caret svg {
    fill: rgba(255, 255, 255, 0.5)
}

[data-bs-theme="dark"] .tox .tox-collection--list .tox-collection__item:not(.tox-collection__item--enabled) .tox-collection__item-checkmark svg {
    display: none
}

[data-bs-theme="dark"] .tox .tox-collection--list .tox-collection__item:not(.tox-collection__item--enabled) .tox-collection__item-accessory + .tox-collection__item-checkmark {
    display: none
}

[data-bs-theme="dark"] .tox .tox-collection--horizontal {
    background-color: #2b3b4e;
    border: 1px solid rgba(255, 255, 255, .15);
    border-radius: 6px;
    box-shadow: 0 0 2px 0 rgba(34, 47, 62, .2), 0 4px 8px 0 rgba(34, 47, 62, .15);
    display: flex;
    flex: 0 0 auto;
    flex-shrink: 0;
    flex-wrap: nowrap;
    margin-bottom: 0;
    overflow-x: auto;
    padding: 0
}

[data-bs-theme="dark"] .tox .tox-collection--horizontal .tox-collection__group {
    align-items: center;
    display: flex;
    flex-wrap: nowrap;
    margin: 0;
    padding: 0 4px
}

[data-bs-theme="dark"] .tox .tox-collection--horizontal .tox-collection__item {
    height: 28px;
    margin: 6px 1px 5px 0;
    padding: 0 4px
}

[data-bs-theme="dark"] .tox .tox-collection--horizontal .tox-collection__item-label {
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-collection--horizontal .tox-collection__item-caret {
    margin-left: 4px
}

[data-bs-theme="dark"] .tox .tox-collection__item-container {
    display: flex
}

[data-bs-theme="dark"] .tox .tox-collection__item-container--row {
    align-items: center;
    flex: 1 1 auto;
    flex-direction: row
}

[data-bs-theme="dark"] .tox .tox-collection__item-container--row.tox-collection__item-container--align-left {
    margin-right: auto
}

[data-bs-theme="dark"] .tox .tox-collection__item-container--row.tox-collection__item-container--align-right {
    justify-content: flex-end;
    margin-left: auto
}

[data-bs-theme="dark"] .tox .tox-collection__item-container--row.tox-collection__item-container--valign-top {
    align-items: flex-start;
    margin-bottom: auto
}

[data-bs-theme="dark"] .tox .tox-collection__item-container--row.tox-collection__item-container--valign-middle {
    align-items: center
}

[data-bs-theme="dark"] .tox .tox-collection__item-container--row.tox-collection__item-container--valign-bottom {
    align-items: flex-end;
    margin-top: auto
}

[data-bs-theme="dark"] .tox .tox-collection__item-container--column {
    align-self: center;
    flex: 1 1 auto;
    flex-direction: column
}

[data-bs-theme="dark"] .tox .tox-collection__item-container--column.tox-collection__item-container--align-left {
    align-items: flex-start
}

[data-bs-theme="dark"] .tox .tox-collection__item-container--column.tox-collection__item-container--align-right {
    align-items: flex-end
}

[data-bs-theme="dark"] .tox .tox-collection__item-container--column.tox-collection__item-container--valign-top {
    align-self: flex-start
}

[data-bs-theme="dark"] .tox .tox-collection__item-container--column.tox-collection__item-container--valign-middle {
    align-self: center
}

[data-bs-theme="dark"] .tox .tox-collection__item-container--column.tox-collection__item-container--valign-bottom {
    align-self: flex-end
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-collection--horizontal .tox-collection__group:not(:last-of-type) {
    border-right: 1px solid transparent
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-collection--list .tox-collection__item > :not(:first-child) {
    margin-left: 8px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-collection--list .tox-collection__item > .tox-collection__item-label:first-child {
    margin-left: 4px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-collection__item-accessory {
    margin-left: 16px;
    text-align: right
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-collection .tox-collection__item-caret {
    margin-left: 16px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-collection--horizontal .tox-collection__group:not(:last-of-type) {
    border-left: 1px solid transparent
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-collection--list .tox-collection__item > :not(:first-child) {
    margin-right: 8px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-collection--list .tox-collection__item > .tox-collection__item-label:first-child {
    margin-right: 4px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-collection__item-accessory {
    margin-right: 16px;
    text-align: left
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-collection .tox-collection__item-caret {
    margin-right: 16px;
    transform: rotateY(180deg)
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-collection--horizontal .tox-collection__item-caret {
    margin-right: 4px
}

@media (forced-colors: active) {
    .tox .tox-hue-slider,
    .tox .tox-rgb-form .tox-rgba-preview {
        background-color: currentColor !important;
        border: 1px solid highlight !important;
        forced-color-adjust: none
    }
}

[data-bs-theme="dark"] .tox .tox-color-picker-container {
    display: flex;
    flex-direction: row;
    height: 225px;
    margin: 0
}

[data-bs-theme="dark"] .tox .tox-sv-palette {
    box-sizing: border-box;
    display: flex;
    height: 100%
}

[data-bs-theme="dark"] .tox .tox-sv-palette-spectrum {
    height: 100%
}

[data-bs-theme="dark"] .tox .tox-sv-palette,
[data-bs-theme="dark"] .tox .tox-sv-palette-spectrum {
    width: 225px
}

[data-bs-theme="dark"] .tox .tox-sv-palette-thumb {
    background: 0 0;
    border: 1px solid #000;
    border-radius: 50%;
    box-sizing: content-box;
    height: 12px;
    position: absolute;
    width: 12px
}

[data-bs-theme="dark"] .tox .tox-sv-palette-inner-thumb {
    border: 1px solid #fff;
    border-radius: 50%;
    height: 10px;
    position: absolute;
    width: 10px
}

[data-bs-theme="dark"] .tox .tox-hue-slider {
    box-sizing: border-box;
    height: 100%;
    width: 25px
}

[data-bs-theme="dark"] .tox .tox-hue-slider-spectrum {
    background: linear-gradient(to bottom, red, #ff0080, #f0f, #8000ff, #00f, #0080ff, #0ff, #00ff80, #0f0, #80ff00, #ff0, #ff8000, red);
    height: 100%;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-hue-slider,
[data-bs-theme="dark"] .tox .tox-hue-slider-spectrum {
    width: 20px
}

[data-bs-theme="dark"] .tox .tox-hue-slider-spectrum:focus,
[data-bs-theme="dark"] .tox .tox-sv-palette-spectrum:focus {
    outline: #08f solid
}

[data-bs-theme="dark"] .tox .tox-hue-slider-thumb {
    background: #fff;
    border: 1px solid #000;
    box-sizing: content-box;
    height: 4px;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-rgb-form {
    display: flex;
    flex-direction: column;
    justify-content: space-between
}

[data-bs-theme="dark"] .tox .tox-rgb-form div {
    align-items: center;
    display: flex;
    justify-content: space-between;
    margin-bottom: 5px;
    width: inherit
}

[data-bs-theme="dark"] .tox .tox-rgb-form input {
    min-width: 6em
}

[data-bs-theme="dark"] .tox .tox-rgb-form input.tox-invalid {
    border: 1px solid red !important;
    box-shadow: 0 0 0 1px red
}

[data-bs-theme="dark"] .tox .tox-rgb-container {
    position: relative
}

[data-bs-theme="dark"] .tox .tox-rgb-form .tox-invalid-icon {
    align-content: center;
    align-items: center;
    display: none;
    height: 100%;
    position: absolute;
    right: 0;
    top: 0
}

[data-bs-theme="dark"] .tox .tox-rgb-form .tox-invalid-icon .tox-control-wrap__status-icon-invalid {
    margin: 0
}

[data-bs-theme="dark"] .tox .tox-rgb-warning-note {
    background-color: #442632;
    border: 1px solid #55212b;
    border-radius: 3px;
    color: #e68080;
    padding: 3px
}

[data-bs-theme="dark"] .tox input.tox-invalid + .tox-invalid-icon {
    display: flex
}

[data-bs-theme="dark"] .tox .tox-rgb-form .tox-rgba-preview {
    border: 1px solid #000;
    flex-grow: 2;
    margin-bottom: 0
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-sv-palette {
    margin-right: 15px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-hue-slider {
    margin-right: 15px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-hue-slider-thumb {
    margin-left: -1px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-rgb-form label {
    margin-right: .5em
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-sv-palette {
    margin-left: 15px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-hue-slider {
    margin-left: 15px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-hue-slider-thumb {
    margin-right: -1px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-rgb-form label {
    margin-left: .5em
}

[data-bs-theme="dark"] .tox .tox-toolbar .tox-swatches,
[data-bs-theme="dark"] .tox .tox-toolbar__overflow .tox-swatches,
[data-bs-theme="dark"] .tox .tox-toolbar__primary .tox-swatches {
    margin: 5px 0 6px 11px
}

[data-bs-theme="dark"] .tox .tox-collection--list .tox-collection__group .tox-swatches-menu {
    border: 0;
    margin: -4px -4px
}

[data-bs-theme="dark"] .tox .tox-swatches__row {
    display: flex
}

@media (forced-colors: active) {
    .tox .tox-swatches__row {
        forced-color-adjust: none
    }
}

[data-bs-theme="dark"] .tox .tox-swatch {
    height: 30px;
    transition: transform .15s, box-shadow .15s;
    width: 30px
}

[data-bs-theme="dark"] .tox .tox-swatch:focus,
[data-bs-theme="dark"] .tox .tox-swatch:hover {
    box-shadow: 0 0 0 1px rgba(127, 127, 127, .3) inset;
    transform: scale(.8)
}

[data-bs-theme="dark"] .tox .tox-swatch--remove {
    align-items: center;
    display: flex;
    justify-content: center
}

[data-bs-theme="dark"] .tox .tox-swatch--remove svg path {
    stroke: #e74c3c
}

[data-bs-theme="dark"] .tox .tox-swatches__picker-btn {
    align-items: center;
    background-color: transparent;
    border: 0;
    cursor: pointer;
    display: flex;
    height: 30px;
    justify-content: center;
    outline: 0;
    padding: 0;
    width: 30px
}

[data-bs-theme="dark"] .tox .tox-swatches__picker-btn svg {
    fill: #fff;
    height: 24px;
    width: 24px
}

[data-bs-theme="dark"] .tox .tox-swatches__picker-btn:hover {
    background: #41474f
}

[data-bs-theme="dark"] .tox div.tox-swatch:not(.tox-swatch--remove) svg {
    display: none;
    fill: #fff;
    height: 24px;
    margin: calc((30px - 24px) / 2) calc((30px - 24px) / 2);
    width: 24px
}

[data-bs-theme="dark"] .tox div.tox-swatch:not(.tox-swatch--remove) svg path {
    fill: #fff;
    paint-order: stroke;
    stroke: var(--bs-body-bg);
    stroke-width: 2px
}

[data-bs-theme="dark"] .tox div.tox-swatch:not(.tox-swatch--remove).tox-collection__item--enabled svg {
    display: block
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-swatches__picker-btn {
    margin-left: auto
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-swatches__picker-btn {
    margin-right: auto
}

[data-bs-theme="dark"] .tox .tox-conversations {
    display: flex;
    flex-direction: column;
    position: relative;
    height: 100%;
    min-width: 300px;
    max-width: 300px;
    width: 300px
}

[data-bs-theme="dark"] .tox .tox-conversations__header {
    align-items: center;
    display: flex;
    justify-content: space-between;
    box-shadow: 0 4px 8px 0 rgba(34, 47, 62, .1);
    padding: 8px 12px;
    background: var(--bs-body-bg)
}

[data-bs-theme="dark"] .tox .tox-conversations__title {
    font-size: 20px;
    font-weight: 400;
    padding: 8px 0 8px 0;
    color: #fff;
    line-height: 28px
}

[data-bs-theme="dark"] .tox .tox-comment {
    background: var(--bs-body-bg);
    border: 1px solid #161f29;
    border-radius: 6px;
    padding: 8px 8px 16px 8px;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-comment:hover {
    box-shadow: 0 4px 8px 0 rgba(34, 47, 62, .1)
}

[data-bs-theme="dark"] .tox .tox-comment.tox-comment--selected {
    background-color: #1b3b60;
    border: 1px solid #006ce7;
    box-shadow: 0 4px 8px 0 rgba(34, 47, 62, .1)
}

[data-bs-theme="dark"] .tox .tox-comment.tox-comment--selected:focus {
    border: 2px solid #fff;
    margin: -1px
}

[data-bs-theme="dark"] .tox .tox-comment.tox-comment--selected:focus:not(:first-child) {
    margin-top: 7px
}

[data-bs-theme="dark"] .tox .tox-comment.tox-comment--selected .tox-comment__single {
    margin-bottom: 12px
}

[data-bs-theme="dark"] .tox .tox-comment.tox-comment--selected .tox-comment__single:focus {
    position: relative
}

[data-bs-theme="dark"] .tox .tox-comment.tox-comment--selected .tox-comment__single:focus::after {
    top: -9px;
    pointer-events: none;
    position: absolute;
    content: "";
    display: block;
    bottom: -9px;
    left: -9px;
    right: -9px;
    border-radius: 6px;
    border: 2px solid #fff
}

[data-bs-theme="dark"] .tox .tox-comment__header {
    align-items: center;
    color: #fff;
    display: flex;
    justify-content: space-between
}

[data-bs-theme="dark"] .tox .tox-comment__date {
    color: #fff;
    font-size: 12px;
    line-height: 18px
}

[data-bs-theme="dark"] .tox .tox-comment__body {
    color: #fff;
    font-size: 14px;
    font-style: normal;
    font-weight: 400;
    line-height: 1.3;
    margin-top: 8px;
    position: relative;
    text-transform: initial;
    transition: max-height .5s cubic-bezier(0, 1, 0, 1);
    white-space: pre-wrap
}

[data-bs-theme="dark"] .tox .tox-comment__body.tox-comment__body--expanded {
    max-height: 100em;
    transition: max-height 1s ease-in-out
}

[data-bs-theme="dark"] .tox .tox-comment__body.tox-comment__body--pending {
    transition: max-height 0s
}

[data-bs-theme="dark"] .tox .tox-comment__body p {
    margin: 0
}

[data-bs-theme="dark"] .tox .tox-comment__body textarea {
    resize: none;
    white-space: normal;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-comment__loading-text {
    align-items: center;
    color: #fff;
    display: flex;
    flex-direction: column;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-comment__loading-text > div {
    padding-bottom: 16px
}

[data-bs-theme="dark"] .tox .tox-comment__overlaytext {
    bottom: 0;
    flex-direction: column;
    font-size: 14px;
    left: 0;
    padding: 1em;
    position: absolute;
    right: 0;
    top: 0;
    z-index: 10
}

[data-bs-theme="dark"] .tox .tox-comment__overlaytext p {
    background-color: var(--bs-body-bg);
    box-shadow: 0 0 8px 8px var(--bs-body-bg);
    color: #fff;
    text-align: center
}

[data-bs-theme="dark"] .tox .tox-comment__overlaytext div:nth-of-type(2) {
    font-size: .8em
}

[data-bs-theme="dark"] .tox .tox-comment__expander {
    padding-top: 8px
}

[data-bs-theme="dark"] .tox .tox-comment__expander p {
    color: rgba(255, 255, 255, .5);
    font-size: 14px;
    font-style: normal
}

[data-bs-theme="dark"] .tox .tox-comment__expander p:focus {
    font-weight: 700
}

[data-bs-theme="dark"] .tox .tox-comment__buttonspacing {
    padding-top: 16px;
    text-align: center
}

[data-bs-theme="dark"] .tox .tox-tbtn.tox-comment__mention-btn {
    display: flex;
    width: 34px;
    height: 34px;
    padding: 5px;
    justify-content: center;
    align-items: center;
    margin: 0;
    background-color: transparent
}

[data-bs-theme="dark"] .tox .tox-comment-thread {
    background: var(--bs-body-bg);
    position: relative;
    border-radius: 6px;
    background-color: transparent
}

[data-bs-theme="dark"] .tox .tox-comment-thread > :not(:first-child) {
    margin-top: 8px
}

[data-bs-theme="dark"] .tox .tox-comment-thread__overlay::after {
    background: var(--bs-body-bg);
    bottom: 0;
    content: "";
    display: flex;
    left: 0;
    opacity: .9;
    position: absolute;
    right: 0;
    top: 0;
    z-index: 5
}

[data-bs-theme="dark"] .tox .tox-comment__reply {
    display: flex;
    flex-shrink: 0;
    flex-wrap: wrap;
    justify-content: flex-end;
    margin-top: 8px
}

[data-bs-theme="dark"] .tox .tox-comment__reply > :first-child {
    margin-bottom: 8px;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-comment__edit {
    display: flex;
    flex-wrap: wrap;
    justify-content: flex-end;
    margin-top: 8px
}

[data-bs-theme="dark"] .tox .tox-comment__gradient::after {
    background: linear-gradient(rgba(34, 47, 62, 0), var(--bs-body-bg));
    bottom: 0;
    content: "";
    display: block;
    height: 5em;
    margin-top: -40px;
    position: absolute;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-comment__overlay {
    background: var(--bs-body-bg);
    bottom: 0;
    display: flex;
    flex-direction: column;
    flex-grow: 1;
    left: 0;
    opacity: .9;
    position: absolute;
    right: 0;
    text-align: center;
    top: 0;
    z-index: 5
}

[data-bs-theme="dark"] .tox .tox-comment__busy-spinner {
    align-items: center;
    background-color: var(--bs-body-bg);
    bottom: 0;
    display: flex;
    justify-content: center;
    left: 0;
    position: absolute;
    right: 0;
    top: 0;
    z-index: 20
}

[data-bs-theme="dark"] .tox .tox-comment__scroll {
    display: flex;
    flex-direction: column;
    flex-shrink: 1;
    overflow: auto;
    padding: 12px;
    scroll-behavior: smooth
}

[data-bs-theme="dark"] .tox .tox-comment--disappearing {
    transition: opacity .5s ease
}

[data-bs-theme="dark"] .tox .tox-comment[data-transitioning-destination=deleting] {
    opacity: 0
}

[data-bs-theme="dark"] .tox .tox-skeleton .tox-skeleton__line {
    height: 16px;
    width: 100%;
    background: linear-gradient(to right, rgba(240, 240, 240, .5) 8%, rgba(240, 240, 240, .7) 18%, rgba(240, 240, 240, .5) 33%);
    animation: wave 2s infinite ease-out
}

[data-bs-theme="dark"] .tox .tox-skeleton .tox-skeleton__circle {
    height: 36px;
    width: 36px;
    margin-right: 8px;
    border-radius: 100%;
    background: linear-gradient(to right, rgba(240, 240, 240, .5) 8%, rgba(240, 240, 240, .7) 18%, rgba(240, 240, 240, .5) 33%);
    animation: wave 2s infinite ease-out
}

@keyframes wave {
    0% {
        background-position: -268px 0
    }
    100% {
        background-position: 268px 0
    }
}

[data-bs-theme="dark"] .tox .tox-ring-loader {
    width: 10px;
    height: 10px;
    border: 1px solid #fff;
    border-bottom-color: transparent;
    border-radius: 50%;
    display: inline-block;
    box-sizing: border-box;
    animation: rotation 1s linear infinite
}

@keyframes rotation {
    0% {
        transform: rotate(0)
    }
    100% {
        transform: rotate(360deg)
    }
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-comment__edit {
    margin-left: 8px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-comment__buttonspacing > :last-child,
[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-comment__edit > :last-child,
[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-comment__reply > :last-child {
    margin-left: 8px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-comment__edit {
    margin-right: 8px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-comment__buttonspacing > :last-child,
[data-bs-theme="dark"] .tox[dir=rtl] .tox-comment__edit > :last-child,
[data-bs-theme="dark"] .tox[dir=rtl] .tox-comment__reply > :last-child {
    margin-right: 8px
}

[data-bs-theme="dark"] .tox .tox-user {
    align-items: center;
    display: flex
}

[data-bs-theme="dark"] .tox .tox-user__avatar svg {
    fill: rgba(255, 255, 255, 0.5)
}

[data-bs-theme="dark"] .tox .tox-user__avatar img {
    border-radius: 50%;
    height: 36px;
    object-fit: cover;
    vertical-align: middle;
    width: 36px
}

[data-bs-theme="dark"] .tox .tox-user__name {
    color: #fff;
    font-size: 14px;
    font-style: normal;
    font-weight: 700;
    line-height: 18px;
    text-transform: none
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-user__avatar img,
[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-user__avatar svg {
    margin-right: 8px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-user__avatar + .tox-user__name {
    margin-left: 8px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-user__avatar img,
[data-bs-theme="dark"] .tox[dir=rtl] .tox-user__avatar svg {
    margin-left: 8px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-user__avatar + .tox-user__name {
    margin-right: 8px
}

[data-bs-theme="dark"] .tox .tox-dialog-wrap {
    align-items: center;
    bottom: 0;
    display: flex;
    justify-content: center;
    left: 0;
    position: fixed;
    right: 0;
    top: 0;
    z-index: 1100
}

[data-bs-theme="dark"] .tox .tox-dialog-wrap__backdrop {
    background-color: rgba(34, 47, 62, .75);
    bottom: 0;
    left: 0;
    position: absolute;
    right: 0;
    top: 0;
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-dialog-wrap__backdrop--opaque {
    background-color: var(--bs-body-bg)
}

[data-bs-theme="dark"] .tox .tox-dialog {
    background-color: #2b3b4e;
    border-color: #161f29;
    border-radius: 10px;
    border-style: solid;
    border-width: 0;
    box-shadow: 0 16px 16px -10px rgba(34, 47, 62, .15), 0 0 40px 1px rgba(34, 47, 62, .15);
    display: flex;
    flex-direction: column;
    max-height: 100%;
    max-width: 480px;
    overflow: hidden;
    position: relative;
    width: 95vw;
    z-index: 2
}

@media only screen and (max-width: 767px) {
    body:not(.tox-force-desktop) .tox .tox-dialog {
        align-self: flex-start;
        margin: 8px auto;
        max-height: calc(100vh - 8px * 2);
        width: calc(100vw - 16px)
    }
}

[data-bs-theme="dark"] .tox .tox-dialog-inline {
    z-index: 1100
}

[data-bs-theme="dark"] .tox .tox-dialog__header {
    align-items: center;
    background-color: #2b3b4e;
    border-bottom: none;
    color: #fff;
    display: flex;
    font-size: 16px;
    justify-content: space-between;
    padding: 8px 16px 0 16px;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-dialog__header .tox-button {
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-dialog__draghandle {
    cursor: grab;
    height: 100%;
    left: 0;
    position: absolute;
    top: 0;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-dialog__draghandle:active {
    cursor: grabbing
}

[data-bs-theme="dark"] .tox .tox-dialog__dismiss {
    margin-left: auto
}

[data-bs-theme="dark"] .tox .tox-dialog__title {
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
    font-size: 20px;
    font-style: normal;
    font-weight: 400;
    line-height: 1.3;
    margin: 0;
    text-transform: none
}

[data-bs-theme="dark"] .tox .tox-dialog__body {
    color: #fff;
    display: flex;
    flex: 1;
    font-size: 16px;
    font-style: normal;
    font-weight: 400;
    line-height: 1.3;
    min-width: 0;
    text-align: left;
    text-transform: none
}

@media only screen and (max-width: 767px) {
    body:not(.tox-force-desktop) .tox .tox-dialog__body {
        flex-direction: column
    }
}

[data-bs-theme="dark"] .tox .tox-dialog__body-nav {
    align-items: flex-start;
    display: flex;
    flex-direction: column;
    flex-shrink: 0;
    padding: 16px 16px
}

@media only screen and (min-width: 768px) {
    .tox .tox-dialog__body-nav {
        max-width: 11em
    }
}

@media only screen and (max-width: 767px) {
    body:not(.tox-force-desktop) .tox .tox-dialog__body-nav {
        flex-direction: row;
        -webkit-overflow-scrolling: touch;
        overflow-x: auto;
        padding-bottom: 0
    }
}

[data-bs-theme="dark"] .tox .tox-dialog__body-nav-item {
    border-bottom: 2px solid transparent;
    color: rgba(255, 255, 255, .5);
    display: inline-block;
    flex-shrink: 0;
    font-size: 14px;
    line-height: 1.3;
    margin-bottom: 8px;
    max-width: 13em;
    -webkit-text-decoration: none;
    text-decoration: none
}

[data-bs-theme="dark"] .tox .tox-dialog__body-nav-item:focus {
    background-color: rgba(0, 108, 231, .1)
}

[data-bs-theme="dark"] .tox .tox-dialog__body-nav-item--active {
    border-bottom: 2px solid #67aeff;
    color: #67aeff
}

@media (forced-colors: active) {
    .tox .tox-dialog__body-nav-item--active {
        border-bottom: 2px solid highlight;
        color: highlight
    }
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content {
    box-sizing: border-box;
    display: flex;
    flex: 1;
    flex-direction: column;
    max-height: min(650px, calc(100vh - 110px));
    overflow: auto;
    -webkit-overflow-scrolling: touch;
    padding: 16px 16px
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content > * {
    margin-bottom: 0;
    margin-top: 16px
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content > :first-child {
    margin-top: 0
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content > :last-child {
    margin-bottom: 0
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content > :only-child {
    margin-bottom: 0;
    margin-top: 0
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content a {
    color: #67aeff;
    cursor: pointer;
    -webkit-text-decoration: underline;
    text-decoration: underline
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content a:focus,
[data-bs-theme="dark"] .tox .tox-dialog__body-content a:hover {
    color: #cde5ff;
    -webkit-text-decoration: underline;
    text-decoration: underline
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content a:focus-visible {
    border-radius: 1px;
    outline: 2px solid #67aeff;
    outline-offset: 2px
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content a:active {
    color: #fff;
    -webkit-text-decoration: underline;
    text-decoration: underline
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content strong {
    font-weight: 700
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content ul {
    list-style-type: disc
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content dd,
[data-bs-theme="dark"] .tox .tox-dialog__body-content ol,
[data-bs-theme="dark"] .tox .tox-dialog__body-content ul {
    padding-inline-start: 2.5rem
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content dl,
[data-bs-theme="dark"] .tox .tox-dialog__body-content ol,
[data-bs-theme="dark"] .tox .tox-dialog__body-content ul {
    margin-bottom: 16px
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content dd,
[data-bs-theme="dark"] .tox .tox-dialog__body-content dl,
[data-bs-theme="dark"] .tox .tox-dialog__body-content dt,
[data-bs-theme="dark"] .tox .tox-dialog__body-content ol,
[data-bs-theme="dark"] .tox .tox-dialog__body-content ul {
    display: block;
    margin-inline-end: 0;
    margin-inline-start: 0
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group h1 {
    color: #fff;
    font-size: 20px;
    font-style: normal;
    font-weight: 700;
    letter-spacing: normal;
    margin-bottom: 16px;
    margin-top: 2rem;
    text-transform: none
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group h2 {
    color: #fff;
    font-size: 16px;
    font-style: normal;
    font-weight: 700;
    letter-spacing: normal;
    margin-bottom: 16px;
    margin-top: 2rem;
    text-transform: none
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group p {
    margin-bottom: 16px
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group h1:first-child,
[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group h2:first-child,
[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group p:first-child {
    margin-top: 0
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group h1:last-child,
[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group h2:last-child,
[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group p:last-child {
    margin-bottom: 0
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group h1:only-child,
[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group h2:only-child,
[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group p:only-child {
    margin-bottom: 0;
    margin-top: 0
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group .tox-label.tox-label--center {
    text-align: center
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-form__group .tox-label.tox-label--end {
    text-align: end
}

[data-bs-theme="dark"] .tox .tox-dialog--width-lg {
    height: 650px;
    max-width: 1200px
}

[data-bs-theme="dark"] .tox .tox-dialog--fullscreen {
    height: 100%;
    max-width: 100%
}

[data-bs-theme="dark"] .tox .tox-dialog--fullscreen .tox-dialog__body-content {
    max-height: 100%
}

[data-bs-theme="dark"] .tox .tox-dialog--width-md {
    max-width: 800px
}

[data-bs-theme="dark"] .tox .tox-dialog--width-md .tox-dialog__body-content {
    overflow: auto
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content--centered {
    text-align: center
}

[data-bs-theme="dark"] .tox .tox-dialog__footer {
    align-items: center;
    background-color: #2b3b4e;
    border-top: none;
    display: flex;
    justify-content: space-between;
    padding: 8px 16px
}

[data-bs-theme="dark"] .tox .tox-dialog__footer-end,
[data-bs-theme="dark"] .tox .tox-dialog__footer-start {
    display: flex
}

[data-bs-theme="dark"] .tox .tox-dialog__busy-spinner {
    align-items: center;
    background-color: rgba(34, 47, 62, .75);
    bottom: 0;
    display: flex;
    justify-content: center;
    left: 0;
    position: absolute;
    right: 0;
    top: 0;
    z-index: 3
}

[data-bs-theme="dark"] .tox .tox-dialog__table {
    border-collapse: collapse;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-dialog__table thead th {
    font-weight: 700;
    padding-bottom: 8px
}

[data-bs-theme="dark"] .tox .tox-dialog__table thead th:first-child {
    padding-right: 8px
}

[data-bs-theme="dark"] .tox .tox-dialog__table tbody tr {
    border-bottom: 1px solid #000
}

[data-bs-theme="dark"] .tox .tox-dialog__table tbody tr:last-child {
    border-bottom: none
}

[data-bs-theme="dark"] .tox .tox-dialog__table td {
    padding-bottom: 8px;
    padding-top: 8px
}

[data-bs-theme="dark"] .tox .tox-dialog__table td:first-child {
    padding-right: 8px
}

[data-bs-theme="dark"] .tox .tox-dialog__iframe {
    min-height: 200px
}

[data-bs-theme="dark"] .tox .tox-dialog__iframe.tox-dialog__iframe--opaque {
    background: #fff
}

[data-bs-theme="dark"] .tox .tox-navobj-bordered {
    position: relative
}

[data-bs-theme="dark"] .tox .tox-navobj-bordered::before {
    border: 1px solid #161f29;
    border-radius: 6px;
    content: '';
    inset: 0;
    opacity: 1;
    pointer-events: none;
    position: absolute;
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-navobj-bordered iframe {
    border-radius: 6px
}

[data-bs-theme="dark"] .tox .tox-navobj-bordered-focus.tox-navobj-bordered::before {
    border-color: #006ce7;
    box-shadow: 0 0 0 1px #006ce7;
    outline: 0
}

[data-bs-theme="dark"] .tox .tox-dialog__popups {
    position: absolute;
    width: 100%;
    z-index: 1100
}

[data-bs-theme="dark"] .tox .tox-dialog__body-iframe {
    display: flex;
    flex: 1;
    flex-direction: column
}

[data-bs-theme="dark"] .tox .tox-dialog__body-iframe .tox-navobj {
    display: flex;
    flex: 1
}

[data-bs-theme="dark"] .tox .tox-dialog__body-iframe .tox-navobj :nth-child(2) {
    flex: 1;
    height: 100%
}

[data-bs-theme="dark"] .tox .tox-dialog-dock-fadeout {
    opacity: 0;
    visibility: hidden
}

[data-bs-theme="dark"] .tox .tox-dialog-dock-fadein {
    opacity: 1;
    visibility: visible
}

[data-bs-theme="dark"] .tox .tox-dialog-dock-transition {
    transition: visibility 0s linear .3s, opacity .3s ease
}

[data-bs-theme="dark"] .tox .tox-dialog-dock-transition.tox-dialog-dock-fadein {
    transition-delay: 0s
}

@media only screen and (max-width: 767px) {
    body:not(.tox-force-desktop) .tox:not([dir=rtl]) .tox-dialog__body-nav {
        margin-right: 0
    }
}

@media only screen and (max-width: 767px) {
    body:not(.tox-force-desktop) .tox:not([dir=rtl]) .tox-dialog__body-nav-item:not(:first-child) {
        margin-left: 8px
    }
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-dialog__footer .tox-dialog__footer-end > *,
[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-dialog__footer .tox-dialog__footer-start > * {
    margin-left: 8px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-dialog__body {
    text-align: right
}

@media only screen and (max-width: 767px) {
    body:not(.tox-force-desktop) .tox[dir=rtl] .tox-dialog__body-nav {
        margin-left: 0
    }
}

@media only screen and (max-width: 767px) {
    body:not(.tox-force-desktop) .tox[dir=rtl] .tox-dialog__body-nav-item:not(:first-child) {
        margin-right: 8px
    }
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-dialog__footer .tox-dialog__footer-end > *,
[data-bs-theme="dark"] .tox[dir=rtl] .tox-dialog__footer .tox-dialog__footer-start > * {
    margin-right: 8px
}

body.tox-dialog__disable-scroll {
    overflow: hidden
}

[data-bs-theme="dark"] .tox .tox-dropzone-container {
    display: flex;
    flex: 1
}

[data-bs-theme="dark"] .tox .tox-dropzone {
    align-items: center;
    background: #fff;
    border: 2px dashed #161f29;
    box-sizing: border-box;
    display: flex;
    flex-direction: column;
    flex-grow: 1;
    justify-content: center;
    min-height: 100px;
    padding: 10px
}

[data-bs-theme="dark"] .tox .tox-dropzone p {
    color: rgba(255, 255, 255, .5);
    margin: 0 0 16px 0
}

[data-bs-theme="dark"] .tox .tox-edit-area {
    display: flex;
    flex: 1;
    overflow: hidden;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-edit-area::before {
    border: 2px solid #fff;
    border-radius: 4px;
    content: '';
    inset: 0;
    opacity: 0;
    pointer-events: none;
    position: absolute;
    transition: opacity .15s;
    z-index: 1
}

@media (forced-colors: active) {
    .tox .tox-edit-area::before {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-edit-area__iframe {
    background-color: #fff;
    border: 0;
    box-sizing: border-box;
    flex: 1;
    height: 100%;
    position: absolute;
    width: 100%
}

[data-bs-theme="dark"] .tox.tox-edit-focus .tox-edit-area::before {
    opacity: 1
}

[data-bs-theme="dark"] .tox.tox-inline-edit-area {
    border: 1px dotted #161f29
}

[data-bs-theme="dark"] .tox .tox-editor-container {
    display: flex;
    flex: 1 1 auto;
    flex-direction: column;
    overflow: hidden
}

[data-bs-theme="dark"] .tox .tox-editor-header {
    display: grid;
    grid-template-columns:1fr min-content;
    z-index: 2
}

[data-bs-theme="dark"] .tox:not(.tox-tinymce-inline) .tox-editor-header {
    background-color: #000;
    border-bottom: 1px solid rgba(255, 255, 255, .15);
    box-shadow: none;
    padding: 4px 0
}

[data-bs-theme="dark"] .tox:not(.tox-tinymce-inline) .tox-editor-header:not(.tox-editor-dock-transition) {
    transition: box-shadow .5s
}

[data-bs-theme="dark"] .tox:not(.tox-tinymce-inline).tox-tinymce--toolbar-bottom .tox-editor-header {
    border-top: 1px solid rgba(255, 255, 255, .15);
    box-shadow: none
}

[data-bs-theme="dark"] .tox:not(.tox-tinymce-inline).tox-tinymce--toolbar-sticky-on .tox-editor-header {
    background-color: var(--bs-body-bg);
    box-shadow: none;
    padding: 4px 0
}

[data-bs-theme="dark"] .tox:not(.tox-tinymce-inline).tox-tinymce--toolbar-sticky-on.tox-tinymce--toolbar-bottom .tox-editor-header {
    box-shadow: none
}

[data-bs-theme="dark"] .tox.tox:not(.tox-tinymce-inline) .tox-editor-header.tox-editor-header--empty {
    background: 0 0;
    border: none;
    box-shadow: none;
    padding: 0
}

[data-bs-theme="dark"] .tox-editor-dock-fadeout {
    opacity: 0;
    visibility: hidden
}

[data-bs-theme="dark"] .tox-editor-dock-fadein {
    opacity: 1;
    visibility: visible
}

[data-bs-theme="dark"] .tox-editor-dock-transition {
    transition: visibility 0s linear .25s, opacity .25s ease
}

[data-bs-theme="dark"] .tox-editor-dock-transition.tox-editor-dock-fadein {
    transition-delay: 0s
}

[data-bs-theme="dark"] .tox .tox-control-wrap {
    flex: 1;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-control-wrap:not(.tox-control-wrap--status-invalid) .tox-control-wrap__status-icon-invalid,
[data-bs-theme="dark"] .tox .tox-control-wrap:not(.tox-control-wrap--status-unknown) .tox-control-wrap__status-icon-unknown,
[data-bs-theme="dark"] .tox .tox-control-wrap:not(.tox-control-wrap--status-valid) .tox-control-wrap__status-icon-valid {
    display: none
}

[data-bs-theme="dark"] .tox .tox-control-wrap svg {
    display: block
}

[data-bs-theme="dark"] .tox .tox-control-wrap__status-icon-wrap {
    position: absolute;
    top: 50%;
    transform: translateY(-50%)
}

[data-bs-theme="dark"] .tox .tox-control-wrap__status-icon-invalid svg {
    fill: #c00
}

[data-bs-theme="dark"] .tox .tox-control-wrap__status-icon-unknown svg {
    fill: orange
}

[data-bs-theme="dark"] .tox .tox-control-wrap__status-icon-valid svg {
    fill: green
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-control-wrap--status-invalid .tox-textfield,
[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-control-wrap--status-unknown .tox-textfield,
[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-control-wrap--status-valid .tox-textfield {
    padding-right: 32px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-control-wrap__status-icon-wrap {
    right: 4px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-control-wrap--status-invalid .tox-textfield,
[data-bs-theme="dark"] .tox[dir=rtl] .tox-control-wrap--status-unknown .tox-textfield,
[data-bs-theme="dark"] .tox[dir=rtl] .tox-control-wrap--status-valid .tox-textfield {
    padding-left: 32px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-control-wrap__status-icon-wrap {
    left: 4px
}

[data-bs-theme="dark"] .tox .tox-custom-preview {
    border-color: #161f29;
    border-radius: 6px;
    border-style: solid;
    border-width: 1px;
    flex: 1;
    padding: 8px
}

[data-bs-theme="dark"] .tox .tox-autocompleter {
    max-width: 25em
}

[data-bs-theme="dark"] .tox .tox-autocompleter .tox-menu {
    box-sizing: border-box;
    max-width: 25em
}

[data-bs-theme="dark"] .tox .tox-autocompleter .tox-autocompleter-highlight {
    font-weight: 700
}

[data-bs-theme="dark"] .tox .tox-color-input {
    display: flex;
    position: relative;
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-color-input .tox-textfield {
    z-index: -1
}

[data-bs-theme="dark"] .tox .tox-color-input span {
    border-color: rgba(34 47 3.1%);
    border-radius: 6px;
    border-style: solid;
    border-width: 1px;
    box-shadow: none;
    box-sizing: border-box;
    height: 24px;
    position: absolute;
    top: 6px;
    width: 24px
}

@media (forced-colors: active) {
    .tox .tox-color-input span {
        border-color: currentColor;
        border-width: 2px !important;
        forced-color-adjust: none
    }
}

[data-bs-theme="dark"] .tox .tox-color-input span:focus:not([aria-disabled=true]),
[data-bs-theme="dark"] .tox .tox-color-input span:hover:not([aria-disabled=true]) {
    border-color: #006ce7;
    cursor: pointer
}

[data-bs-theme="dark"] .tox .tox-color-input span::before {
    background-image: linear-gradient(45deg, rgba(255, 255, 255, .25) 25%, transparent 25%), linear-gradient(-45deg, rgba(255, 255, 255, .25) 25%, transparent 25%), linear-gradient(45deg, transparent 75%, rgba(255, 255, 255, .25) 75%), linear-gradient(-45deg, transparent 75%, rgba(255, 255, 255, .25) 75%);
    background-position: 0 0, 0 6px, 6px -6px, -6px 0;
    background-size: 12px 12px;
    border: 1px solid #2b3b4e;
    border-radius: 6px;
    box-sizing: border-box;
    content: '';
    height: 24px;
    left: -1px;
    position: absolute;
    top: -1px;
    width: 24px;
    z-index: -1
}

@media (forced-colors: active) {
    .tox .tox-color-input span::before {
        border: none
    }
}

[data-bs-theme="dark"] .tox .tox-color-input span[aria-disabled=true] {
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-color-input .tox-textfield {
    padding-left: 36px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-color-input span {
    left: 6px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-color-input .tox-textfield {
    padding-right: 36px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-color-input span {
    right: 6px
}

[data-bs-theme="dark"] .tox .tox-label,
[data-bs-theme="dark"] .tox .tox-toolbar-label {
    color: rgba(255, 255, 255, .5);
    display: block;
    font-size: 14px;
    font-style: normal;
    font-weight: 400;
    line-height: 1.3;
    padding: 0 8px 0 0;
    text-transform: none;
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-toolbar-label {
    padding: 0 8px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-label {
    padding: 0 0 0 8px
}

[data-bs-theme="dark"] .tox .tox-form {
    display: flex;
    flex: 1;
    flex-direction: column
}

[data-bs-theme="dark"] .tox .tox-form__group {
    box-sizing: border-box;
    margin-bottom: 4px
}

[data-bs-theme="dark"] .tox .tox-form-group--maximize {
    flex: 1
}

[data-bs-theme="dark"] .tox .tox-form__group--error {
    color: #c00
}

[data-bs-theme="dark"] .tox .tox-form__group--collection {
    display: flex
}

[data-bs-theme="dark"] .tox .tox-form__grid {
    display: flex;
    flex-direction: row;
    flex-wrap: wrap;
    justify-content: space-between
}

[data-bs-theme="dark"] .tox .tox-form__grid--2col > .tox-form__group {
    width: calc(50% - (8px / 2))
}

[data-bs-theme="dark"] .tox .tox-form__grid--3col > .tox-form__group {
    width: calc(100% / 3 - (8px / 2))
}

[data-bs-theme="dark"] .tox .tox-form__grid--4col > .tox-form__group {
    width: calc(25% - (8px / 2))
}

[data-bs-theme="dark"] .tox .tox-form__controls-h-stack {
    align-items: center;
    display: flex
}

[data-bs-theme="dark"] .tox .tox-form__group--inline {
    align-items: center;
    display: flex
}

[data-bs-theme="dark"] .tox .tox-form__group--stretched {
    display: flex;
    flex: 1;
    flex-direction: column
}

[data-bs-theme="dark"] .tox .tox-form__group--stretched .tox-textarea {
    flex: 1
}

[data-bs-theme="dark"] .tox .tox-form__group--stretched .tox-navobj {
    display: flex;
    flex: 1
}

[data-bs-theme="dark"] .tox .tox-form__group--stretched .tox-navobj :nth-child(2) {
    flex: 1;
    height: 100%
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-form__controls-h-stack > :not(:first-child) {
    margin-left: 4px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-form__controls-h-stack > :not(:first-child) {
    margin-right: 4px
}

[data-bs-theme="dark"] .tox .tox-lock.tox-locked .tox-lock-icon__unlock,
[data-bs-theme="dark"] .tox .tox-lock:not(.tox-locked) .tox-lock-icon__lock {
    display: none
}

[data-bs-theme="dark"] .tox .tox-listboxfield .tox-listbox--select,
[data-bs-theme="dark"] .tox .tox-textarea,
[data-bs-theme="dark"] .tox .tox-textarea-wrap .tox-textarea:focus,
[data-bs-theme="dark"] .tox .tox-textfield,
[data-bs-theme="dark"] .tox .tox-toolbar-textfield {
    appearance: none;
    background-color: #2b3b4e;
    border-color: #161f29;
    border-radius: 6px;
    border-style: solid;
    border-width: 1px;
    box-shadow: none;
    box-sizing: border-box;
    color: #fff;
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
    font-size: 16px;
    line-height: 24px;
    margin: 0;
    min-height: 34px;
    outline: 0;
    padding: 5px 5.5px;
    resize: none;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-textarea[disabled],
[data-bs-theme="dark"] .tox .tox-textfield[disabled] {
    background-color: var(--bs-body-bg);
    color: rgba(255, 255, 255, .85);
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-custom-editor:focus-within,
[data-bs-theme="dark"] .tox .tox-listboxfield .tox-listbox--select:focus,
[data-bs-theme="dark"] .tox .tox-textarea-wrap:focus-within,
[data-bs-theme="dark"] .tox .tox-textarea:focus,
[data-bs-theme="dark"] .tox .tox-textfield:focus {
    background-color: #2b3b4e;
    border-color: #006ce7;
    box-shadow: 0 0 0 1px #006ce7;
    outline: 0
}

[data-bs-theme="dark"] .tox .tox-toolbar-textfield {
    border-width: 0;
    margin-bottom: 3px;
    margin-top: 2px;
    max-width: 250px
}

[data-bs-theme="dark"] .tox .tox-naked-btn {
    background-color: transparent;
    border: 0;
    border-color: transparent;
    box-shadow: unset;
    color: #006ce7;
    cursor: pointer;
    display: block;
    margin: 0;
    padding: 0
}

[data-bs-theme="dark"] .tox .tox-naked-btn svg {
    display: block;
    fill: #fff
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-toolbar-textfield + * {
    margin-left: 4px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-toolbar-textfield + * {
    margin-right: 4px
}

[data-bs-theme="dark"] .tox .tox-listboxfield {
    cursor: pointer;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-listboxfield .tox-listbox--select[disabled] {
    background-color: #19232e;
    color: rgba(255, 255, 255, .85);
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-listbox__select-label {
    cursor: default;
    flex: 1;
    margin: 0 4px
}

[data-bs-theme="dark"] .tox .tox-listbox__select-chevron {
    align-items: center;
    display: flex;
    justify-content: center;
    width: 16px
}

[data-bs-theme="dark"] .tox .tox-listbox__select-chevron svg {
    fill: #fff
}

@media (forced-colors: active) {
    .tox .tox-listbox__select-chevron svg {
        fill: currentColor !important
    }
}

[data-bs-theme="dark"] .tox .tox-listboxfield .tox-listbox--select {
    align-items: center;
    display: flex
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-listboxfield svg {
    right: 8px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-listboxfield svg {
    left: 8px
}

[data-bs-theme="dark"] .tox .tox-selectfield {
    cursor: pointer;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-selectfield select {
    appearance: none;
    background-color: #2b3b4e;
    border-color: #161f29;
    border-radius: 6px;
    border-style: solid;
    border-width: 1px;
    box-shadow: none;
    box-sizing: border-box;
    color: #fff;
    font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Oxygen-Sans, Ubuntu, Cantarell, "Helvetica Neue", sans-serif;
    font-size: 16px;
    line-height: 24px;
    margin: 0;
    min-height: 34px;
    outline: 0;
    padding: 5px 5.5px;
    resize: none;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-selectfield select[disabled] {
    background-color: #19232e;
    color: rgba(255, 255, 255, .85);
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-selectfield select::-ms-expand {
    display: none
}

[data-bs-theme="dark"] .tox .tox-selectfield select:focus {
    background-color: #2b3b4e;
    border-color: #006ce7;
    box-shadow: 0 0 0 1px #006ce7;
    outline: 0
}

[data-bs-theme="dark"] .tox .tox-selectfield svg {
    pointer-events: none;
    position: absolute;
    top: 50%;
    transform: translateY(-50%)
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-selectfield select[size="0"],
[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-selectfield select[size="1"] {
    padding-right: 24px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-selectfield svg {
    right: 8px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-selectfield select[size="0"],
[data-bs-theme="dark"] .tox[dir=rtl] .tox-selectfield select[size="1"] {
    padding-left: 24px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-selectfield svg {
    left: 8px
}

[data-bs-theme="dark"] .tox .tox-textarea-wrap {
    border-color: #161f29;
    border-radius: 6px;
    border-style: solid;
    border-width: 1px;
    display: flex;
    flex: 1;
    overflow: hidden
}

[data-bs-theme="dark"] .tox .tox-textarea {
    appearance: textarea;
    white-space: pre-wrap
}

[data-bs-theme="dark"] .tox .tox-textarea-wrap .tox-textarea {
    border: none
}

[data-bs-theme="dark"] .tox .tox-textarea-wrap .tox-textarea:focus {
    border: none
}

[data-bs-theme="dark"] .tox-fullscreen {
    border: 0;
    height: 100%;
    margin: 0;
    overflow: hidden;
    overscroll-behavior: none;
    padding: 0;
    touch-action: pinch-zoom;
    width: 100%
}

[data-bs-theme="dark"] .tox.tox-tinymce.tox-fullscreen .tox-statusbar__resize-handle {
    display: none
}

[data-bs-theme="dark"] .tox-shadowhost.tox-fullscreen,
[data-bs-theme="dark"] .tox.tox-tinymce.tox-fullscreen {
    left: 0;
    position: fixed;
    top: 0;
    z-index: 1200
}

[data-bs-theme="dark"] .tox.tox-tinymce.tox-fullscreen {
    background-color: transparent
}

[data-bs-theme="dark"] .tox-fullscreen .tox.tox-tinymce-aux,
[data-bs-theme="dark"] .tox-fullscreen ~ .tox.tox-tinymce-aux {
    z-index: 1201
}

[data-bs-theme="dark"] .tox .tox-help__more-link {
    list-style: none;
    margin-top: 1em
}

[data-bs-theme="dark"] .tox .tox-imagepreview {
    background-color: #666;
    height: 380px;
    overflow: hidden;
    position: relative;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-imagepreview.tox-imagepreview__loaded {
    overflow: auto
}

[data-bs-theme="dark"] .tox .tox-imagepreview__container {
    display: flex;
    left: 100vw;
    position: absolute;
    top: 100vw
}

[data-bs-theme="dark"] .tox .tox-imagepreview__image {
    background: url(data:image/gif;base64,R0lGODdhDAAMAIABAMzMzP///ywAAAAADAAMAAACFoQfqYeabNyDMkBQb81Uat85nxguUAEAOw==)
}

[data-bs-theme="dark"] .tox .tox-image-tools .tox-spacer {
    flex: 1
}

[data-bs-theme="dark"] .tox .tox-image-tools .tox-bar {
    align-items: center;
    display: flex;
    height: 60px;
    justify-content: center
}

[data-bs-theme="dark"] .tox .tox-image-tools .tox-imagepreview,
[data-bs-theme="dark"] .tox .tox-image-tools .tox-imagepreview + .tox-bar {
    margin-top: 8px
}

[data-bs-theme="dark"] .tox .tox-image-tools .tox-croprect-block {
    background: #000;
    opacity: .5;
    position: absolute;
    zoom: 1
}

[data-bs-theme="dark"] .tox .tox-image-tools .tox-croprect-handle {
    border: 2px solid #fff;
    height: 20px;
    left: 0;
    position: absolute;
    top: 0;
    width: 20px
}

[data-bs-theme="dark"] .tox .tox-image-tools .tox-croprect-handle-move {
    border: 0;
    cursor: move;
    position: absolute
}

[data-bs-theme="dark"] .tox .tox-image-tools .tox-croprect-handle-nw {
    border-width: 2px 0 0 2px;
    cursor: nw-resize;
    left: 100px;
    margin: -2px 0 0 -2px;
    top: 100px
}

[data-bs-theme="dark"] .tox .tox-image-tools .tox-croprect-handle-ne {
    border-width: 2px 2px 0 0;
    cursor: ne-resize;
    left: 200px;
    margin: -2px 0 0 -20px;
    top: 100px
}

[data-bs-theme="dark"] .tox .tox-image-tools .tox-croprect-handle-sw {
    border-width: 0 0 2px 2px;
    cursor: sw-resize;
    left: 100px;
    margin: -20px 2px 0 -2px;
    top: 200px
}

[data-bs-theme="dark"] .tox .tox-image-tools .tox-croprect-handle-se {
    border-width: 0 2px 2px 0;
    cursor: se-resize;
    left: 200px;
    margin: -20px 0 0 -20px;
    top: 200px
}

[data-bs-theme="dark"] .tox .tox-insert-table-picker {
    background-color: var(--bs-body-bg);
    display: flex;
    flex-wrap: wrap;
    width: 170px
}

[data-bs-theme="dark"] .tox .tox-insert-table-picker > div {
    border-color: rgba(255, 255, 255, .15);
    border-style: solid;
    border-width: 0 1px 1px 0;
    box-sizing: border-box;
    height: 17px;
    width: 17px
}

[data-bs-theme="dark"] .tox .tox-collection--list .tox-collection__group .tox-insert-table-picker {
    margin: -4px -4px
}

[data-bs-theme="dark"] .tox .tox-insert-table-picker .tox-insert-table-picker__selected {
    background-color: #006ce7;
    border-color: rgba(255, 255, 255, .15)
}

@media (forced-colors: active) {
    .tox .tox-insert-table-picker .tox-insert-table-picker__selected {
        border-color: Highlight;
        filter: contrast(50%)
    }
}

[data-bs-theme="dark"] .tox .tox-insert-table-picker__label {
    color: #fff;
    display: block;
    font-size: 14px;
    padding: 4px;
    text-align: center;
    width: 100%
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-insert-table-picker > div:nth-child(10n) {
    border-right: 0
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-insert-table-picker > div:nth-child(10n+1) {
    border-right: 0
}

[data-bs-theme="dark"] .tox .tox-menu {
    background-color: #2b3b4e;
    border: 1px solid rgba(255, 255, 255, .15);
    border-radius: 6px;
    box-shadow: none;
    display: inline-block;
    overflow: hidden;
    vertical-align: top;
    z-index: 1150
}

[data-bs-theme="dark"] .tox .tox-menu.tox-collection.tox-collection--list {
    padding: 0 4px
}

[data-bs-theme="dark"] .tox .tox-menu.tox-collection.tox-collection--toolbar {
    padding: 8px
}

[data-bs-theme="dark"] .tox .tox-menu.tox-collection.tox-collection--grid {
    padding: 8px
}

@media only screen and (min-width: 768px) {
    .tox .tox-menu .tox-collection__item-label {
        overflow-wrap: break-word;
        word-break: normal
    }

    .tox .tox-dialog__popups .tox-menu .tox-collection__item-label {
        word-break: break-all
    }
}

[data-bs-theme="dark"] .tox .tox-menu__label blockquote,
[data-bs-theme="dark"] .tox .tox-menu__label code,
[data-bs-theme="dark"] .tox .tox-menu__label h1,
[data-bs-theme="dark"] .tox .tox-menu__label h2,
[data-bs-theme="dark"] .tox .tox-menu__label h3,
[data-bs-theme="dark"] .tox .tox-menu__label h4,
[data-bs-theme="dark"] .tox .tox-menu__label h5,
[data-bs-theme="dark"] .tox .tox-menu__label h6,
[data-bs-theme="dark"] .tox .tox-menu__label p {
    margin: 0
}

[data-bs-theme="dark"] .tox .tox-menubar {
    background: repeating-linear-gradient(transparent 0 1px, transparent 1px 39px) center top 39px/100% calc(100% - 39px) no-repeat;
    background-color: var(--bs-body-bg);
    display: flex;
    flex: 0 0 auto;
    flex-shrink: 0;
    flex-wrap: wrap;
    grid-column: 1/-1;
    grid-row: 1;
    padding: 0 11px 0 12px
}

[data-bs-theme="dark"] .tox .tox-promotion + .tox-menubar {
    grid-column: 1
}

[data-bs-theme="dark"] .tox .tox-promotion {
    background: repeating-linear-gradient(transparent 0 1px, transparent 1px 39px) center top 39px/100% calc(100% - 39px) no-repeat;
    background-color: var(--bs-body-bg);
    grid-column: 2;
    grid-row: 1;
    padding-inline-end: 8px;
    padding-inline-start: 4px;
    padding-top: 5px
}

[data-bs-theme="dark"] .tox .tox-promotion-link {
    align-items: unsafe center;
    background-color: #e8f1f8;
    border-radius: 5px;
    color: #086be6;
    cursor: pointer;
    display: flex;
    font-size: 14px;
    height: 26.6px;
    padding: 4px 8px;
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-promotion-link:hover {
    background-color: #b4d7ff
}

[data-bs-theme="dark"] .tox .tox-promotion-link:focus {
    background-color: #d9edf7
}

[data-bs-theme="dark"] .tox .tox-mbtn {
    align-items: center;
    background: var(--bs-body-bg);
    border: 0;
    border-radius: 3px;
    box-shadow: none;
    color: #fff;
    display: flex;
    flex: 0 0 auto;
    font-size: 14px;
    font-style: normal;
    font-weight: 400;
    height: 28px;
    justify-content: center;
    margin: 5px 1px 6px 0;
    outline: 0;
    padding: 0 4px;
    text-transform: none;
    width: auto
}

[data-bs-theme="dark"] .tox .tox-mbtn[disabled] {
    background-color: var(--bs-body-bg);
    border: 0;
    box-shadow: none;
    color: rgba(255, 255, 255, .5);
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-mbtn:focus:not(:disabled) {
    background: var(--bs-body-bg);
    border: 0;
    box-shadow: none;
    color: #fff;
    position: relative;
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-mbtn:focus:not(:disabled)::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

@media (forced-colors: active) {
    .tox .tox-mbtn:focus:not(:disabled)::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-mbtn--active,
[data-bs-theme="dark"] .tox .tox-mbtn:not(:disabled).tox-mbtn--active:focus {
    background: #599fef;
    border: 0;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-mbtn:hover:not(:disabled):not(.tox-mbtn--active) {
    background: #41474f;
    border: 0;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-mbtn__select-label {
    cursor: default;
    font-weight: 400;
    margin: 0 4px
}

[data-bs-theme="dark"] .tox .tox-mbtn[disabled] .tox-mbtn__select-label {
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-mbtn__select-chevron {
    align-items: center;
    display: flex;
    justify-content: center;
    width: 16px;
    display: none
}

[data-bs-theme="dark"] .tox .tox-notification {
    border-radius: 6px;
    border-style: solid;
    border-width: 1px;
    box-shadow: none;
    box-sizing: border-box;
    display: grid;
    font-size: 14px;
    font-weight: 400;
    grid-template-columns:minmax(40px, 1fr) auto minmax(40px, 1fr);
    margin-left: auto;
    margin-right: auto;
    margin-top: 4px;
    opacity: 0;
    padding: 4px;
    transition: transform .1s ease-in, opacity 150ms ease-in;
    width: max-content
}

[data-bs-theme="dark"] .tox .tox-notification a {
    cursor: pointer;
    -webkit-text-decoration: underline;
    text-decoration: underline
}

[data-bs-theme="dark"] .tox .tox-notification p {
    font-size: 14px;
    font-weight: 400
}

[data-bs-theme="dark"] .tox .tox-notification:focus {
    border-color: #006ce7;
    box-shadow: 0 0 0 1px #006ce7
}

[data-bs-theme="dark"] .tox .tox-notification--in {
    opacity: 1
}

[data-bs-theme="dark"] .tox .tox-notification--success {
    background-color: #334840;
    border-color: #3c5440;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-notification--success p {
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-notification--success a {
    color: #b5d199
}

[data-bs-theme="dark"] .tox .tox-notification--success a:focus,
[data-bs-theme="dark"] .tox .tox-notification--success a:hover {
    color: #82b153;
    -webkit-text-decoration: underline;
    text-decoration: underline
}

[data-bs-theme="dark"] .tox .tox-notification--success a:focus-visible {
    border-radius: 1px;
    outline: 2px solid #b5d199;
    outline-offset: 2px
}

[data-bs-theme="dark"] .tox .tox-notification--success a:active {
    color: #689041;
    -webkit-text-decoration: underline;
    text-decoration: underline
}

[data-bs-theme="dark"] .tox .tox-notification--success svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-notification--error {
    background-color: #442632;
    border-color: #55212b;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-notification--error p {
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-notification--error a {
    color: #e68080
}

[data-bs-theme="dark"] .tox .tox-notification--error a:focus,
[data-bs-theme="dark"] .tox .tox-notification--error a:hover {
    color: #d42b2b;
    -webkit-text-decoration: underline;
    text-decoration: underline
}

[data-bs-theme="dark"] .tox .tox-notification--error a:focus-visible {
    border-radius: 1px;
    outline: 2px solid #e68080;
    outline-offset: 2px
}

[data-bs-theme="dark"] .tox .tox-notification--error a:active {
    color: #a22;
    -webkit-text-decoration: underline;
    text-decoration: underline
}

[data-bs-theme="dark"] .tox .tox-notification--error svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-notification--warn,
[data-bs-theme="dark"] .tox .tox-notification--warning {
    background-color: var(--bs-body-bg);
    border-color: rgba(255, 255, 255, .15);
    color: #fff0b3
}

[data-bs-theme="dark"] .tox .tox-notification--warn p,
[data-bs-theme="dark"] .tox .tox-notification--warning p {
    color: #fff0b3
}

[data-bs-theme="dark"] .tox .tox-notification--warn a,
[data-bs-theme="dark"] .tox .tox-notification--warning a {
    color: #fc0
}

[data-bs-theme="dark"] .tox .tox-notification--warn a:focus,
[data-bs-theme="dark"] .tox .tox-notification--warn a:hover,
[data-bs-theme="dark"] .tox .tox-notification--warning a:focus,
[data-bs-theme="dark"] .tox .tox-notification--warning a:hover {
    color: #997a00;
    -webkit-text-decoration: underline;
    text-decoration: underline
}

[data-bs-theme="dark"] .tox .tox-notification--warn a:focus-visible,
[data-bs-theme="dark"] .tox .tox-notification--warning a:focus-visible {
    border-radius: 1px;
    outline: 2px solid #ffcc00;
    outline-offset: 2px
}

[data-bs-theme="dark"] .tox .tox-notification--warn a:active,
[data-bs-theme="dark"] .tox .tox-notification--warning a:active {
    color: #665200;
    -webkit-text-decoration: underline;
    text-decoration: underline
}

[data-bs-theme="dark"] .tox .tox-notification--warn svg,
[data-bs-theme="dark"] .tox .tox-notification--warning svg {
    fill: #fff0b3
}

[data-bs-theme="dark"] .tox .tox-notification--info {
    background-color: #254161;
    border-color: #264972;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-notification--info p {
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-notification--info a {
    color: #83b7f3
}

[data-bs-theme="dark"] .tox .tox-notification--info a:focus,
[data-bs-theme="dark"] .tox .tox-notification--info a:hover {
    color: #2681ea;
    -webkit-text-decoration: underline;
    text-decoration: underline
}

[data-bs-theme="dark"] .tox .tox-notification--info a:focus-visible {
    border-radius: 1px;
    outline: 2px solid #83b7f3;
    outline-offset: 2px
}

[data-bs-theme="dark"] .tox .tox-notification--info a:active {
    color: #1368c9;
    -webkit-text-decoration: underline;
    text-decoration: underline
}

[data-bs-theme="dark"] .tox .tox-notification--info svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-notification__body {
    align-self: center;
    color: #fff;
    font-size: 14px;
    grid-column-end: 3;
    grid-column-start: 2;
    grid-row-end: 2;
    grid-row-start: 1;
    text-align: center;
    white-space: normal;
    word-break: break-all;
    word-break: break-word
}

[data-bs-theme="dark"] .tox .tox-notification__body > * {
    margin: 0
}

[data-bs-theme="dark"] .tox .tox-notification__body > * + * {
    margin-top: 1rem
}

[data-bs-theme="dark"] .tox .tox-notification__icon {
    align-self: center;
    grid-column-end: 2;
    grid-column-start: 1;
    grid-row-end: 2;
    grid-row-start: 1;
    justify-self: end
}

[data-bs-theme="dark"] .tox .tox-notification__icon svg {
    display: block
}

[data-bs-theme="dark"] .tox .tox-notification__dismiss {
    align-self: start;
    grid-column-end: 4;
    grid-column-start: 3;
    grid-row-end: 2;
    grid-row-start: 1;
    justify-self: end
}

[data-bs-theme="dark"] .tox .tox-notification .tox-progress-bar {
    grid-column-end: 4;
    grid-column-start: 1;
    grid-row-end: 3;
    grid-row-start: 2;
    justify-self: center
}

[data-bs-theme="dark"] .tox .tox-notification-container-dock-fadeout {
    opacity: 0;
    visibility: hidden
}

[data-bs-theme="dark"] .tox .tox-notification-container-dock-fadein {
    opacity: 1;
    visibility: visible
}

[data-bs-theme="dark"] .tox .tox-notification-container-dock-transition {
    transition: visibility 0s linear .3s, opacity .3s ease
}

[data-bs-theme="dark"] .tox .tox-notification-container-dock-transition.tox-notification-container-dock-fadein {
    transition-delay: 0s
}

[data-bs-theme="dark"] .tox .tox-pop {
    display: inline-block;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-pop--resizing {
    transition: width .1s ease
}

[data-bs-theme="dark"] .tox .tox-pop--resizing .tox-toolbar,
[data-bs-theme="dark"] .tox .tox-pop--resizing .tox-toolbar__group {
    flex-wrap: nowrap
}

[data-bs-theme="dark"] .tox .tox-pop--transition {
    transition: .15s ease;
    transition-property: left, right, top, bottom
}

[data-bs-theme="dark"] .tox .tox-pop--transition::after,
[data-bs-theme="dark"] .tox .tox-pop--transition::before {
    transition: all .15s, visibility 0s, opacity 75ms ease 75ms
}

[data-bs-theme="dark"] .tox .tox-pop__dialog {
    background-color: var(--bs-body-bg);
    border: 1px solid #161f29;
    border-radius: 6px;
    box-shadow: 0 0 2px 0 rgba(34, 47, 62, .2), 0 4px 8px 0 rgba(34, 47, 62, .15);
    min-width: 0;
    overflow: hidden
}

[data-bs-theme="dark"] .tox .tox-pop__dialog > :not(.tox-toolbar) {
    margin: 4px 4px 4px 8px
}

[data-bs-theme="dark"] .tox .tox-pop__dialog .tox-toolbar {
    background-color: transparent;
    margin-bottom: -1px
}

[data-bs-theme="dark"] .tox .tox-pop::after,
[data-bs-theme="dark"] .tox .tox-pop::before {
    border-style: solid;
    content: '';
    display: block;
    height: 0;
    opacity: 1;
    position: absolute;
    width: 0
}

@media (forced-colors: active) {
    .tox .tox-pop::after,
    .tox .tox-pop::before {
        content: none
    }
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--inset::after,
[data-bs-theme="dark"] .tox .tox-pop.tox-pop--inset::before {
    opacity: 0;
    transition: all 0s .15s, visibility 0s, opacity 75ms ease
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--bottom::after,
[data-bs-theme="dark"] .tox .tox-pop.tox-pop--bottom::before {
    left: 50%;
    top: 100%
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--bottom::after {
    border-color: var(--bs-body-bg) transparent transparent transparent;
    border-width: 8px;
    margin-left: -8px;
    margin-top: -1px
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--bottom::before {
    border-color: #161f29 transparent transparent transparent;
    border-width: 9px;
    margin-left: -9px
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--top::after,
[data-bs-theme="dark"] .tox .tox-pop.tox-pop--top::before {
    left: 50%;
    top: 0;
    transform: translateY(-100%)
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--top::after {
    border-color: transparent transparent var(--bs-body-bg) transparent;
    border-width: 8px;
    margin-left: -8px;
    margin-top: 1px
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--top::before {
    border-color: transparent transparent #161f29 transparent;
    border-width: 9px;
    margin-left: -9px
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--left::after,
[data-bs-theme="dark"] .tox .tox-pop.tox-pop--left::before {
    left: 0;
    top: calc(50% - 1px);
    transform: translateY(-50%)
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--left::after {
    border-color: transparent var(--bs-body-bg) transparent transparent;
    border-width: 8px;
    margin-left: -15px
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--left::before {
    border-color: transparent #161f29 transparent transparent;
    border-width: 10px;
    margin-left: -19px
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--right::after,
[data-bs-theme="dark"] .tox .tox-pop.tox-pop--right::before {
    left: 100%;
    top: calc(50% + 1px);
    transform: translateY(-50%)
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--right::after {
    border-color: transparent transparent transparent var(--bs-body-bg);
    border-width: 8px;
    margin-left: -1px
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--right::before {
    border-color: transparent transparent transparent #161f29;
    border-width: 10px;
    margin-left: -1px
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--align-left::after,
[data-bs-theme="dark"] .tox .tox-pop.tox-pop--align-left::before {
    left: 20px
}

[data-bs-theme="dark"] .tox .tox-pop.tox-pop--align-right::after,
[data-bs-theme="dark"] .tox .tox-pop.tox-pop--align-right::before {
    left: calc(100% - 20px)
}

[data-bs-theme="dark"] .tox .tox-sidebar-wrap {
    display: flex;
    flex-direction: row;
    flex-grow: 1;
    min-height: 0
}

[data-bs-theme="dark"] .tox .tox-sidebar {
    background-color: #34485f;
    display: flex;
    flex-direction: row;
    justify-content: flex-end
}

[data-bs-theme="dark"] .tox .tox-sidebar__slider {
    display: flex;
    overflow: hidden
}

[data-bs-theme="dark"] .tox .tox-sidebar__pane-container {
    display: flex
}

[data-bs-theme="dark"] .tox .tox-sidebar__pane {
    display: flex
}

[data-bs-theme="dark"] .tox .tox-sidebar--sliding-closed {
    opacity: 0
}

[data-bs-theme="dark"] .tox .tox-sidebar--sliding-open {
    opacity: 1
}

[data-bs-theme="dark"] .tox .tox-sidebar--sliding-growing,
[data-bs-theme="dark"] .tox .tox-sidebar--sliding-shrinking {
    transition: width .5s ease, opacity .5s ease
}

[data-bs-theme="dark"] .tox .tox-selector {
    background-color: #4099ff;
    border-color: #4099ff;
    border-style: solid;
    border-width: 1px;
    box-sizing: border-box;
    display: inline-block;
    height: 10px;
    position: absolute;
    width: 10px
}

[data-bs-theme="dark"] .tox.tox-platform-touch .tox-selector {
    height: 12px;
    width: 12px
}

[data-bs-theme="dark"] .tox .tox-slider {
    align-items: center;
    display: flex;
    flex: 1;
    height: 24px;
    justify-content: center;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-slider__rail {
    background-color: transparent;
    border: 1px solid #161f29;
    border-radius: 6px;
    height: 10px;
    min-width: 120px;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-slider__handle {
    background-color: #006ce7;
    border: 2px solid #0054b4;
    border-radius: 6px;
    box-shadow: none;
    height: 24px;
    left: 50%;
    position: absolute;
    top: 50%;
    transform: translateX(-50%) translateY(-50%);
    width: 14px
}

[data-bs-theme="dark"] .tox .tox-form__controls-h-stack > .tox-slider:not(:first-of-type) {
    margin-inline-start: 8px
}

[data-bs-theme="dark"] .tox .tox-form__controls-h-stack > .tox-form__group + .tox-slider {
    margin-inline-start: 32px
}

[data-bs-theme="dark"] .tox .tox-form__controls-h-stack > .tox-slider + .tox-form__group {
    margin-inline-start: 32px
}

[data-bs-theme="dark"] .tox .tox-source-code {
    overflow: auto
}

[data-bs-theme="dark"] .tox .tox-spinner {
    display: flex
}

[data-bs-theme="dark"] .tox .tox-spinner > div {
    animation: tam-bouncing-dots 1.5s ease-in-out 0s infinite both;
    background-color: rgba(255, 255, 255, .5);
    border-radius: 100%;
    height: 8px;
    width: 8px
}

[data-bs-theme="dark"] .tox .tox-spinner > div:first-child {
    animation-delay: -.32s
}

[data-bs-theme="dark"] .tox .tox-spinner > div:nth-child(2) {
    animation-delay: -.16s
}

@keyframes tam-bouncing-dots {
    0%,
    100%,
    80% {
        transform: scale(0)
    }
    40% {
        transform: scale(1)
    }
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-spinner > div:not(:first-child) {
    margin-left: 4px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-spinner > div:not(:first-child) {
    margin-right: 4px
}

[data-bs-theme="dark"] .tox .tox-statusbar {
    align-items: center;
    background-color: var(--bs-body-bg);
    border-top: 1px solid rgba(255, 255, 255, .15);
    color: rgba(255, 255, 255, .75);
    display: flex;
    flex: 0 0 auto;
    font-size: 14px;
    font-weight: 400;
    height: 25px;
    overflow: hidden;
    padding: 0 8px;
    position: relative;
    text-transform: none
}

[data-bs-theme="dark"] .tox .tox-statusbar__path {
    display: flex;
    flex: 1 1 auto;
    text-overflow: ellipsis;
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-statusbar__right-container {
    display: flex;
    justify-content: flex-end;
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-statusbar__help-text {
    text-align: center
}

[data-bs-theme="dark"] .tox .tox-statusbar__text-container {
    align-items: flex-start;
    display: flex;
    flex: 1 1 auto;
    height: 16px;
    justify-content: space-between
}

@media only screen and (min-width: 768px) {
    .tox .tox-statusbar__text-container.tox-statusbar__text-container-3-cols > .tox-statusbar__help-text,
    .tox .tox-statusbar__text-container.tox-statusbar__text-container-3-cols > .tox-statusbar__path,
    .tox .tox-statusbar__text-container.tox-statusbar__text-container-3-cols > .tox-statusbar__right-container {
        flex: 0 0 calc(100% / 3)
    }
}

[data-bs-theme="dark"] .tox .tox-statusbar__text-container.tox-statusbar__text-container--flex-end {
    justify-content: flex-end
}

[data-bs-theme="dark"] .tox .tox-statusbar__text-container.tox-statusbar__text-container--flex-start {
    justify-content: flex-start
}

[data-bs-theme="dark"] .tox .tox-statusbar__text-container.tox-statusbar__text-container--space-around {
    justify-content: space-around
}

[data-bs-theme="dark"] .tox .tox-statusbar__path > * {
    display: inline;
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-statusbar__wordcount {
    flex: 0 0 auto;
    margin-left: 1ch
}

@media only screen and (max-width: 767px) {
    .tox .tox-statusbar__text-container .tox-statusbar__help-text {
        display: none
    }

    .tox .tox-statusbar__text-container .tox-statusbar__help-text:only-child {
        display: block
    }
}

[data-bs-theme="dark"] .tox .tox-statusbar a,
[data-bs-theme="dark"] .tox .tox-statusbar__path-item,
[data-bs-theme="dark"] .tox .tox-statusbar__wordcount {
    color: rgba(255, 255, 255, .75);
    position: relative;
    -webkit-text-decoration: none;
    text-decoration: none
}

[data-bs-theme="dark"] .tox .tox-statusbar a:focus:not(:disabled):not([aria-disabled=true]),
[data-bs-theme="dark"] .tox .tox-statusbar a:hover:not(:disabled):not([aria-disabled=true]),
[data-bs-theme="dark"] .tox .tox-statusbar__path-item:focus:not(:disabled):not([aria-disabled=true]),
[data-bs-theme="dark"] .tox .tox-statusbar__path-item:hover:not(:disabled):not([aria-disabled=true]),
[data-bs-theme="dark"] .tox .tox-statusbar__wordcount:focus:not(:disabled):not([aria-disabled=true]),
[data-bs-theme="dark"] .tox .tox-statusbar__wordcount:hover:not(:disabled):not([aria-disabled=true]) {
    color: #fff;
    cursor: pointer
}

[data-bs-theme="dark"] .tox .tox-statusbar a:focus-visible::after,
[data-bs-theme="dark"] .tox .tox-statusbar__path-item:focus-visible::after,
[data-bs-theme="dark"] .tox .tox-statusbar__wordcount:focus-visible::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

@media (forced-colors: active) {
    .tox .tox-statusbar a:focus-visible::after,
    .tox .tox-statusbar__path-item:focus-visible::after,
    .tox .tox-statusbar__wordcount:focus-visible::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-statusbar__branding svg {
    fill: rgba(255, 255, 255, 0.8);
    height: 1em;
    margin-left: .3em;
    width: auto
}

@media (forced-colors: active) {
    .tox .tox-statusbar__branding svg {
        fill: currentColor
    }
}

[data-bs-theme="dark"] .tox .tox-statusbar__branding a {
    align-items: center;
    display: inline-flex
}

[data-bs-theme="dark"] .tox .tox-statusbar__branding a:focus:not(:disabled):not([aria-disabled=true]) svg,
[data-bs-theme="dark"] .tox .tox-statusbar__branding a:hover:not(:disabled):not([aria-disabled=true]) svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-statusbar__resize-handle {
    align-items: flex-end;
    align-self: stretch;
    cursor: nwse-resize;
    display: flex;
    flex: 0 0 auto;
    justify-content: flex-end;
    margin-bottom: 3px;
    margin-left: 4px;
    margin-right: calc(3px - 8px);
    margin-top: 3px;
    padding-bottom: 0;
    padding-left: 0;
    padding-right: 0;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-statusbar__resize-handle svg {
    display: block;
    fill: rgba(255, 255, 255, 0.5)
}

[data-bs-theme="dark"] .tox .tox-statusbar__resize-handle:focus svg,
[data-bs-theme="dark"] .tox .tox-statusbar__resize-handle:hover svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-statusbar__resize-handle:focus-visible {
    background-color: transparent;
    border-radius: 1px 1px 5px 1px;
    box-shadow: 0 0 0 2px transparent
}

[data-bs-theme="dark"] .tox .tox-statusbar__resize-handle:focus-visible::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

@media (forced-colors: active) {
    .tox .tox-statusbar__resize-handle:focus-visible::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-statusbar__resize-handle:only-child {
    margin-left: auto
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-statusbar__path > * {
    margin-right: 4px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-statusbar__branding {
    margin-left: 2ch
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-statusbar {
    flex-direction: row-reverse
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-statusbar__path > * {
    margin-left: 4px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-statusbar__branding svg {
    margin-left: 0;
    margin-right: .3em
}

[data-bs-theme="dark"] .tox .tox-throbber {
    z-index: 1299
}

[data-bs-theme="dark"] .tox .tox-throbber__busy-spinner {
    align-items: center;
    background-color: rgba(34, 47, 62, .6);
    bottom: 0;
    display: flex;
    justify-content: center;
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

[data-bs-theme="dark"] .tox .tox-tbtn {
    align-items: center;
    background: var(--bs-body-bg);
    border: 0;
    border-radius: 3px;
    box-shadow: none;
    color: #fff;
    display: flex;
    flex: 0 0 auto;
    font-size: 14px;
    font-style: normal;
    font-weight: 400;
    height: 28px;
    justify-content: center;
    margin: 6px 1px 5px 0;
    outline: 0;
    padding: 0;
    text-transform: none;
    width: 34px
}

@media (forced-colors: active) {
    .tox .tox-tbtn.tox-tbtn:hover,
    .tox .tox-tbtn:hover {
        outline: 1px dashed currentColor
    }

    .tox .tox-tbtn.tox-tbtn--active,
    .tox .tox-tbtn.tox-tbtn--enabled,
    .tox .tox-tbtn.tox-tbtn--enabled:focus,
    .tox .tox-tbtn.tox-tbtn--enabled:hover,
    .tox .tox-tbtn:focus:not(.tox-tbtn--disabled) {
        outline: 1px solid currentColor;
        position: relative
    }
}

[data-bs-theme="dark"] .tox .tox-tbtn svg {
    display: block;
    fill: #fff
}

@media (forced-colors: active) {
    .tox .tox-tbtn svg {
        fill: currentColor !important
    }

    .tox .tox-tbtn svg.tox-tbtn--enabled,
    .tox .tox-tbtn svg:focus:not(.tox-tbtn--disabled) {
        fill: currentColor !important
    }

    .tox .tox-tbtn svg .tox-tbtn:disabled,
    .tox .tox-tbtn svg .tox-tbtn:disabled:hover,
    .tox .tox-tbtn svg.tox-tbtn--disabled,
    .tox .tox-tbtn svg.tox-tbtn--disabled:hover {
        filter: contrast(0%)
    }
}

[data-bs-theme="dark"] .tox .tox-tbtn.tox-tbtn-more {
    padding-left: 5px;
    padding-right: 5px;
    width: inherit
}

[data-bs-theme="dark"] .tox .tox-tbtn:focus {
    background: var(--bs-body-bg);
    border: 0;
    box-shadow: none;
    position: relative;
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-tbtn:focus::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

@media (forced-colors: active) {
    .tox .tox-tbtn:focus::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-tbtn:hover {
    background: #41474f;
    border: 0;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-tbtn:hover svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tbtn:active {
    background: #599fef;
    border: 0;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-tbtn:active svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tbtn--disabled .tox-tbtn--enabled svg {
    fill: rgba(255, 255, 255, 0.5)
}

[data-bs-theme="dark"] .tox .tox-tbtn--disabled,
[data-bs-theme="dark"] .tox .tox-tbtn--disabled:hover,
[data-bs-theme="dark"] .tox .tox-tbtn:disabled,
[data-bs-theme="dark"] .tox .tox-tbtn:disabled:hover {
    background: var(--bs-body-bg);
    border: 0;
    box-shadow: none;
    color: rgba(255, 255, 255, .5);
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-tbtn--disabled svg,
[data-bs-theme="dark"] .tox .tox-tbtn--disabled:hover svg,
[data-bs-theme="dark"] .tox .tox-tbtn:disabled svg,
[data-bs-theme="dark"] .tox .tox-tbtn:disabled:hover svg {
    fill: rgba(255, 255, 255, 0.5)
}

[data-bs-theme="dark"] .tox .tox-tbtn--active,
[data-bs-theme="dark"] .tox .tox-tbtn--enabled,
[data-bs-theme="dark"] .tox .tox-tbtn--enabled:focus,
[data-bs-theme="dark"] .tox .tox-tbtn--enabled:hover {
    background: #599fef;
    border: 0;
    box-shadow: none;
    color: #fff;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-tbtn--active > *,
[data-bs-theme="dark"] .tox .tox-tbtn--enabled:focus > *,
[data-bs-theme="dark"] .tox .tox-tbtn--enabled:hover > *,
[data-bs-theme="dark"] .tox .tox-tbtn--enabled > * {
    transform: none
}

[data-bs-theme="dark"] .tox .tox-tbtn--active svg,
[data-bs-theme="dark"] .tox .tox-tbtn--enabled svg,
[data-bs-theme="dark"] .tox .tox-tbtn--enabled:focus svg,
[data-bs-theme="dark"] .tox .tox-tbtn--enabled:hover svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tbtn--active.tox-tbtn--disabled svg,
[data-bs-theme="dark"] .tox .tox-tbtn--enabled.tox-tbtn--disabled svg,
[data-bs-theme="dark"] .tox .tox-tbtn--enabled:focus.tox-tbtn--disabled svg,
[data-bs-theme="dark"] .tox .tox-tbtn--enabled:hover.tox-tbtn--disabled svg {
    fill: rgba(255, 255, 255, 0.5)
}

[data-bs-theme="dark"] .tox .tox-tbtn--enabled:focus::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

@media (forced-colors: active) {
    .tox .tox-tbtn--enabled:focus::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-tbtn:focus:not(.tox-tbtn--disabled) {
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-tbtn:focus:not(.tox-tbtn--disabled) svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tbtn:active > * {
    transform: none
}

[data-bs-theme="dark"] .tox .tox-tbtn--md {
    height: 42px;
    width: 51px
}

[data-bs-theme="dark"] .tox .tox-tbtn--lg {
    flex-direction: column;
    height: 56px;
    width: 68px
}

[data-bs-theme="dark"] .tox .tox-tbtn--return {
    align-self: stretch;
    height: unset;
    width: 16px
}

[data-bs-theme="dark"] .tox .tox-tbtn--labeled {
    padding: 0 4px;
    width: unset
}

[data-bs-theme="dark"] .tox .tox-tbtn__vlabel {
    display: block;
    font-size: 10px;
    font-weight: 400;
    letter-spacing: -.025em;
    margin-bottom: 4px;
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-number-input {
    background: #41474f;
    border-radius: 3px;
    display: flex;
    margin: 6px 1px 5px 0;
    position: relative;
    width: auto
}

[data-bs-theme="dark"] .tox .tox-number-input:focus {
    background: #41474f
}

[data-bs-theme="dark"] .tox .tox-number-input:focus::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

@media (forced-colors: active) {
    .tox .tox-number-input:focus::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-number-input .tox-input-wrapper {
    display: flex;
    pointer-events: none;
    position: relative;
    text-align: center
}

[data-bs-theme="dark"] .tox .tox-number-input .tox-input-wrapper:focus {
    background-color: #41474f;
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-number-input .tox-input-wrapper:focus::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

@media (forced-colors: active) {
    .tox .tox-number-input .tox-input-wrapper:focus::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-number-input .tox-input-wrapper:has(input:focus)::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

@media (forced-colors: active) {
    .tox .tox-number-input .tox-input-wrapper:has(input:focus)::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-number-input input {
    border-radius: 3px;
    color: #fff;
    font-size: 14px;
    margin: 2px 0;
    pointer-events: all;
    position: relative;
    width: 60px
}

[data-bs-theme="dark"] .tox .tox-number-input input:hover {
    background: #41474f;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-number-input input:focus {
    background-color: #41474f
}

[data-bs-theme="dark"] .tox .tox-number-input input:disabled {
    background: var(--bs-body-bg);
    border: 0;
    box-shadow: none;
    color: rgba(255, 255, 255, .5);
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-number-input button {
    color: #fff;
    height: 28px;
    position: relative;
    text-align: center;
    width: 24px
}

@media (forced-colors: active) {
    .tox .tox-number-input button:active,
    .tox .tox-number-input button:focus,
    .tox .tox-number-input button:hover {
        outline: 1px solid currentColor !important
    }
}

[data-bs-theme="dark"] .tox .tox-number-input button svg {
    display: block;
    fill: #fff;
    margin: 0 auto;
    transform: scale(.67)
}

@media (forced-colors: active) {
    .tox .tox-number-input button svg,
    .tox .tox-number-input button svg:active,
    .tox .tox-number-input button svg:hover {
        fill: currentColor !important
    }

    .tox .tox-number-input button svg:disabled {
        filter: contrast(0)
    }
}

[data-bs-theme="dark"] .tox .tox-number-input button:focus {
    background: #41474f;
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-number-input button:focus::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

@media (forced-colors: active) {
    .tox .tox-number-input button:focus::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-number-input button:hover {
    background: #41474f;
    border: 0;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-number-input button:hover svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-number-input button:active {
    background: #599fef;
    border: 0;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-number-input button:active svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-number-input button:disabled {
    background: var(--bs-body-bg);
    border: 0;
    box-shadow: none;
    color: rgba(255, 255, 255, .5);
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-number-input button:disabled svg {
    fill: rgba(255, 255, 255, 0.5)
}

[data-bs-theme="dark"] .tox .tox-number-input button.minus {
    border-radius: 3px 0 0 3px
}

[data-bs-theme="dark"] .tox .tox-number-input button.plus {
    border-radius: 0 3px 3px 0
}

[data-bs-theme="dark"] .tox .tox-number-input:focus:not(:active) > .tox-input-wrapper,
[data-bs-theme="dark"] .tox .tox-number-input:focus:not(:active) > button {
    background: #41474f
}

[data-bs-theme="dark"] .tox .tox-tbtn--select {
    margin: 6px 1px 5px 0;
    padding: 0 4px;
    width: auto
}

[data-bs-theme="dark"] .tox .tox-tbtn__select-label {
    cursor: default;
    font-weight: 400;
    height: initial;
    margin: 0 4px;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-tbtn__select-chevron {
    align-items: center;
    display: flex;
    justify-content: center;
    width: 16px
}

[data-bs-theme="dark"] .tox .tox-tbtn__select-chevron svg {
    fill: rgba(255, 255, 255, 0.5)
}

@media (forced-colors: active) {
    .tox .tox-tbtn__select-chevron svg {
        fill: currentColor
    }
}

[data-bs-theme="dark"] .tox .tox-tbtn--bespoke {
    background: #41474f
}

[data-bs-theme="dark"] .tox .tox-tbtn--bespoke:focus {
    background: #41474f
}

[data-bs-theme="dark"] .tox .tox-tbtn--bespoke + .tox-tbtn--bespoke {
    margin-inline-start: 4px
}

[data-bs-theme="dark"] .tox .tox-tbtn--bespoke .tox-tbtn__select-label {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    width: 7em
}

[data-bs-theme="dark"] .tox .tox-tbtn--disabled .tox-tbtn__select-label,
[data-bs-theme="dark"] .tox .tox-tbtn--select:disabled .tox-tbtn__select-label {
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-split-button {
    border: 0;
    border-radius: 3px;
    box-sizing: border-box;
    display: flex;
    margin: 6px 1px 5px 0
}

[data-bs-theme="dark"] .tox .tox-split-button:hover {
    box-shadow: 0 0 0 1px #41474f inset
}

[data-bs-theme="dark"] .tox .tox-split-button:focus {
    background: var(--bs-body-bg);
    box-shadow: none;
    color: #fff;
    position: relative;
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-split-button:focus::after {
    pointer-events: none;
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0
}

@media (forced-colors: active) {
    .tox .tox-split-button:focus::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-split-button > * {
    border-radius: 0
}

[data-bs-theme="dark"] .tox .tox-split-button > :first-child {
    border-bottom-left-radius: 3px;
    border-top-left-radius: 3px
}

[data-bs-theme="dark"] .tox .tox-split-button > :nth-child(2) {
    border-bottom-right-radius: 3px;
    border-top-right-radius: 3px
}

[data-bs-theme="dark"] .tox .tox-split-button__chevron {
    width: 16px
}

[data-bs-theme="dark"] .tox .tox-split-button__chevron svg {
    fill: rgba(255, 255, 255, 0.5)
}

@media (forced-colors: active) {
    .tox .tox-split-button__chevron svg {
        fill: currentColor
    }
}

[data-bs-theme="dark"] .tox .tox-split-button .tox-tbtn {
    margin: 0
}

[data-bs-theme="dark"] .tox .tox-split-button:focus .tox-tbtn {
    background-color: transparent
}

[data-bs-theme="dark"] .tox .tox-split-button.tox-tbtn--disabled .tox-tbtn:focus,
[data-bs-theme="dark"] .tox .tox-split-button.tox-tbtn--disabled .tox-tbtn:hover,
[data-bs-theme="dark"] .tox .tox-split-button.tox-tbtn--disabled:focus,
[data-bs-theme="dark"] .tox .tox-split-button.tox-tbtn--disabled:hover {
    background: var(--bs-body-bg);
    box-shadow: none;
    color: rgba(255, 255, 255, .5)
}

[data-bs-theme="dark"] .tox.tox-platform-touch .tox-split-button .tox-tbtn--select {
    padding: 0 0
}

[data-bs-theme="dark"] .tox.tox-platform-touch .tox-split-button .tox-tbtn:not(.tox-tbtn--select):first-child {
    width: 30px
}

[data-bs-theme="dark"] .tox.tox-platform-touch .tox-split-button__chevron {
    width: 20px
}

[data-bs-theme="dark"] .tox .tox-split-button.tox-tbtn--disabled svg .tox-icon-highlight-bg-color__color,
[data-bs-theme="dark"] .tox .tox-split-button.tox-tbtn--disabled svg .tox-icon-text-color__color {
    opacity: .3
}

[data-bs-theme="dark"] .tox .tox-toolbar-overlord {
    background-color: var(--bs-body-bg)
}

[data-bs-theme="dark"] .tox .tox-toolbar,
[data-bs-theme="dark"] .tox .tox-toolbar__overflow,
[data-bs-theme="dark"] .tox .tox-toolbar__primary {
    background-attachment: local;
    background-color: var(--bs-body-bg);
    background-image: repeating-linear-gradient(rgba(255, 255, 255, .15) 0 1px, transparent 1px 39px);
    background-position: center top 40px;
    background-repeat: no-repeat;
    background-size: calc(100% - 11px * 2) calc(100% - 41px);
    display: flex;
    flex: 0 0 auto;
    flex-shrink: 0;
    flex-wrap: wrap;
    padding: 0 0;
    transform: perspective(1px)
}

[data-bs-theme="dark"] .tox .tox-toolbar-overlord > .tox-toolbar,
[data-bs-theme="dark"] .tox .tox-toolbar-overlord > .tox-toolbar__overflow,
[data-bs-theme="dark"] .tox .tox-toolbar-overlord > .tox-toolbar__primary {
    background-position: center top 0;
    background-size: calc(100% - 11px * 2) calc(100% - 0px)
}

[data-bs-theme="dark"] .tox .tox-toolbar__overflow.tox-toolbar__overflow--closed {
    height: 0;
    opacity: 0;
    padding-bottom: 0;
    padding-top: 0;
    visibility: hidden
}

[data-bs-theme="dark"] .tox .tox-toolbar__overflow--growing {
    transition: height .3s ease, opacity .2s linear .1s
}

[data-bs-theme="dark"] .tox .tox-toolbar__overflow--shrinking {
    transition: opacity .3s ease, height .2s linear .1s, visibility 0s linear .3s
}

[data-bs-theme="dark"] .tox .tox-anchorbar,
[data-bs-theme="dark"] .tox .tox-toolbar-overlord {
    grid-column: 1/-1
}

[data-bs-theme="dark"] .tox .tox-menubar + .tox-toolbar,
[data-bs-theme="dark"] .tox .tox-menubar + .tox-toolbar-overlord {
    border-top: 1px solid transparent;
    margin-top: -1px;
    padding-bottom: 1px;
    padding-top: 1px
}

@media (forced-colors: active) {
    .tox .tox-menubar + .tox-toolbar,
    .tox .tox-menubar + .tox-toolbar-overlord {
        outline: 1px solid currentColor
    }
}

[data-bs-theme="dark"] .tox .tox-toolbar--scrolling {
    flex-wrap: nowrap;
    overflow-x: auto
}

[data-bs-theme="dark"] .tox .tox-pop .tox-toolbar {
    border-width: 0
}

[data-bs-theme="dark"] .tox .tox-toolbar--no-divider {
    background-image: none
}

[data-bs-theme="dark"] .tox .tox-toolbar-overlord .tox-toolbar:not(.tox-toolbar--scrolling):first-child,
[data-bs-theme="dark"] .tox .tox-toolbar-overlord .tox-toolbar__primary {
    background-position: center top 39px
}

[data-bs-theme="dark"] .tox .tox-editor-header > .tox-toolbar--scrolling,
[data-bs-theme="dark"] .tox .tox-toolbar-overlord .tox-toolbar--scrolling:first-child {
    background-image: none
}

[data-bs-theme="dark"] .tox.tox-tinymce-aux .tox-toolbar__overflow {
    background-color: var(--bs-body-bg);
    background-position: center top 43px;
    background-size: calc(100% - 8px * 2) calc(100% - 51px);
    border: none;
    border-radius: 6px;
    box-shadow: 0 0 2px 0 rgba(34, 47, 62, .2), 0 4px 8px 0 rgba(34, 47, 62, .15);
    overscroll-behavior: none;
    padding: 4px 0
}

@media (forced-colors: active) {
    .tox.tox-tinymce-aux .tox-toolbar__overflow {
        border: solid
    }
}

[data-bs-theme="dark"] .tox-pop .tox-pop__dialog .tox-toolbar {
    background-position: center top 43px;
    background-size: calc(100% - 11px * 2) calc(100% - 51px);
    padding: 4px 0
}

[data-bs-theme="dark"] .tox .tox-toolbar__group {
    align-items: center;
    display: flex;
    flex-wrap: wrap;
    margin: 0 0;
    padding: 0 11px 0 12px
}

[data-bs-theme="dark"] .tox .tox-toolbar__group--pull-right {
    margin-left: auto
}

[data-bs-theme="dark"] .tox .tox-toolbar--scrolling .tox-toolbar__group {
    flex-shrink: 0;
    flex-wrap: nowrap
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-toolbar__group:not(:last-of-type) {
    border-right: 1px solid transparent
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-toolbar__group:not(:last-of-type) {
    border-left: 1px solid transparent
}

[data-bs-theme="dark"] .tox .tox-tooltip {
    display: inline-block;
    max-width: 15em;
    padding: 8px;
    pointer-events: none;
    position: relative;
    width: max-content;
    z-index: 1150
}

[data-bs-theme="dark"] .tox .tox-tooltip__body {
    background-color: #324053;
    border-radius: 6px;
    box-shadow: none;
    color: #fff;
    font-size: 12px;
    font-style: normal;
    font-weight: 600;
    overflow-wrap: break-word;
    padding: 4px 6px;
    text-transform: none
}

@media (forced-colors: active) {
    .tox .tox-tooltip__body {
        outline: outset 1px
    }
}

[data-bs-theme="dark"] .tox .tox-tooltip__arrow {
    position: absolute
}

[data-bs-theme="dark"] .tox .tox-tooltip--down .tox-tooltip__arrow {
    border-left: 8px solid transparent;
    border-right: 8px solid transparent;
    border-top: 8px solid #324053;
    bottom: 0;
    left: 50%;
    position: absolute;
    transform: translateX(-50%)
}

[data-bs-theme="dark"] .tox .tox-tooltip--up .tox-tooltip__arrow {
    border-bottom: 8px solid #324053;
    border-left: 8px solid transparent;
    border-right: 8px solid transparent;
    left: 50%;
    position: absolute;
    top: 0;
    transform: translateX(-50%)
}

[data-bs-theme="dark"] .tox .tox-tooltip--right .tox-tooltip__arrow {
    border-bottom: 8px solid transparent;
    border-left: 8px solid #324053;
    border-top: 8px solid transparent;
    position: absolute;
    right: 0;
    top: 50%;
    transform: translateY(-50%)
}

[data-bs-theme="dark"] .tox .tox-tooltip--left .tox-tooltip__arrow {
    border-bottom: 8px solid transparent;
    border-right: 8px solid #324053;
    border-top: 8px solid transparent;
    left: 0;
    position: absolute;
    top: 50%;
    transform: translateY(-50%)
}

[data-bs-theme="dark"] .tox .tox-tree {
    display: flex;
    flex-direction: column
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn {
    align-items: center;
    background: 0 0;
    border: 0;
    border-radius: 4px;
    box-shadow: none;
    color: #fff;
    display: flex;
    flex: 0 0 auto;
    font-size: 14px;
    font-style: normal;
    font-weight: 400;
    height: 28px;
    margin-bottom: 4px;
    margin-top: 4px;
    outline: 0;
    overflow: hidden;
    padding: 0;
    padding-left: 8px;
    text-transform: none
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn .tox-tree__label {
    cursor: default;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn svg {
    display: block;
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn:focus {
    background: #41474f;
    border: 0;
    box-shadow: none
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn:hover {
    background: #41474f;
    border: 0;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn:hover svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn:active {
    background: #599fef;
    border: 0;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn:active svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn--disabled,
[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn--disabled:hover,
[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn:disabled,
[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn:disabled:hover {
    background: 0 0;
    border: 0;
    box-shadow: none;
    color: rgba(255, 255, 255, .5);
    cursor: not-allowed
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn--disabled svg,
[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn--disabled:hover svg,
[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn:disabled svg,
[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn:disabled:hover svg {
    fill: rgba(255, 255, 255, 0.5)
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn--enabled,
[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn--enabled:hover {
    background: #599fef;
    border: 0;
    box-shadow: none;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn--enabled:hover > *,
[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn--enabled > * {
    transform: none
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn--enabled svg,
[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn--enabled:hover svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn:focus:not(.tox-trbtn--disabled) {
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn:focus:not(.tox-trbtn--disabled) svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn:active > * {
    transform: none
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn--return {
    align-self: stretch;
    height: unset;
    width: 16px
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn--labeled {
    padding: 0 4px;
    width: unset
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn__vlabel {
    display: block;
    font-size: 10px;
    font-weight: 400;
    letter-spacing: -.025em;
    margin-bottom: 4px;
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory {
    display: flex;
    flex-direction: column
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label {
    font-weight: 700
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label .tox-mbtn {
    margin-left: auto
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label .tox-mbtn svg {
    fill: transparent
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label .tox-mbtn.tox-mbtn--active svg,
[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label .tox-mbtn:focus svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label:focus .tox-mbtn svg,
[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label:hover .tox-mbtn svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label:hover:has(.tox-mbtn:hover) {
    background-color: transparent;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label:hover:has(.tox-mbtn:hover) .tox-chevron svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label .tox-chevron {
    margin-right: 6px
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label:has(+ .tox-tree--directory__children--growing) .tox-chevron,
[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label:has(+ .tox-tree--directory__children--shrinking) .tox-chevron {
    transition: transform .5s ease-in-out
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label:has(+ .tox-tree--directory__children--growing) .tox-chevron,
[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory .tox-tree--directory__label:has(+ .tox-tree--directory__children--open) .tox-chevron {
    transform: rotate(90deg)
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--leaf__label {
    font-weight: 400
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--leaf__label .tox-mbtn {
    margin-left: auto
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--leaf__label .tox-mbtn svg {
    fill: transparent
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--leaf__label .tox-mbtn.tox-mbtn--active svg,
[data-bs-theme="dark"] .tox .tox-tree .tox-tree--leaf__label .tox-mbtn:focus svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--leaf__label:hover .tox-mbtn svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--leaf__label:hover:has(.tox-mbtn:hover) {
    background-color: transparent;
    color: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--leaf__label:hover:has(.tox-mbtn:hover) .tox-chevron svg {
    fill: #fff
}

[data-bs-theme="dark"] .tox .tox-tree .tox-icon-custom-state {
    flex-grow: 1;
    display: flex;
    justify-content: flex-end
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory__children {
    overflow: hidden;
    padding-left: 16px
}

[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory__children.tox-tree--directory__children--growing,
[data-bs-theme="dark"] .tox .tox-tree .tox-tree--directory__children.tox-tree--directory__children--shrinking {
    transition: height .5s ease-in-out
}

[data-bs-theme="dark"] .tox .tox-tree .tox-trbtn.tox-tree--leaf__label {
    display: flex;
    justify-content: space-between
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__pane {
    padding: 0 !important
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__container {
    display: flex;
    flex-direction: column;
    height: 100%
}

[data-bs-theme="dark"] .tox .tox-revisionhistory {
    background-color: var(--bs-body-bg);
    border-top: 1px solid rgba(255, 255, 255, .15);
    display: flex;
    flex: 1;
    height: 100%;
    margin-top: 8px;
    overflow-x: auto;
    overflow-y: hidden;
    position: relative;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-revisionhistory--align-right {
    margin-left: auto
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__iframe {
    flex: 1
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar {
    display: flex;
    flex-direction: column;
    height: 100%;
    min-width: 248px;
    width: 316px
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__sidebar-title {
    background-color: var(--bs-body-bg);
    box-shadow: 0 4px 8px 0 rgba(34, 47, 62, .1);
    color: #fff;
    font-size: 20px;
    font-weight: 400;
    line-height: 28px;
    padding: 12px;
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions {
    background-color: #2b3b4e;
    display: flex;
    flex: 1;
    flex-direction: column;
    gap: 12px;
    overflow-y: auto;
    padding: 10px 12px
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions:focus {
    height: 100%;
    position: relative;
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions:focus::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0;
    border-radius: 6px;
    bottom: 1px;
    left: 1px;
    right: 1px;
    top: 1px
}

@media (forced-colors: active) {
    .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions:focus::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card {
    background-color: var(--bs-body-bg);
    border: 1px solid rgba(255, 255, 255, .15);
    border-radius: 6px;
    color: #fff;
    cursor: pointer;
    display: flex;
    flex-direction: column;
    font-size: 14px;
    gap: 12px;
    padding: 12px;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card:hover {
    box-shadow: 0 4px 8px 0 rgba(34, 47, 62, .1)
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card:focus {
    position: relative;
    z-index: 1
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card:focus::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff #285ec7;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0;
    border-radius: 6px;
    box-shadow: 0 0 0 2px #285ec7;
    box-shadow: 0 0 0 2px #285ec7 !important
}

@media (forced-colors: active) {
    .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card:focus::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card.tox-revisionhistory__card--selected {
    background-color: #62430b;
    box-shadow: 0 4px 8px 0 rgba(34, 47, 62, .1);
    position: relative
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card.tox-revisionhistory__card--selected::after {
    border-radius: 3px;
    bottom: 0;
    box-shadow: 0 0 0 2px #fff #cea215;
    content: '';
    left: 0;
    position: absolute;
    right: 0;
    top: 0;
    border-radius: 6px;
    box-shadow: 0 0 0 2px #cea215
}

@media (forced-colors: active) {
    .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card.tox-revisionhistory__card--selected::after {
        border: 2px solid highlight
    }
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card-date {
    display: flex;
    gap: 12px;
    justify-content: space-between
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card-date-label {
    font-size: 16px;
    line-height: 24px
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card-label {
    font-size: 12px;
    font-weight: 600;
    line-height: 24px;
    padding: 0
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card-author {
    align-items: center;
    display: flex;
    flex: 1 0 0;
    gap: 8px;
    height: 36px
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card-author-name {
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    font-size: 14px;
    font-weight: 700;
    line-height: 18px
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__avatar {
    border-radius: 50%;
    height: 36px;
    object-fit: cover;
    vertical-align: middle;
    width: 36px
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__norevision {
    color: rgba(255, 255, 255, .5);
    font-size: 16px;
    line-height: 24px;
    padding: 5px 5.5px
}

[data-bs-theme="dark"] .tox .tox-revisionhistory__sidebar .tox-revisionhistory__revisions .tox-revisionhistory__card-check-icon {
    color: #fff;
    height: 24px
}

[data-bs-theme="dark"] .tox .tox-view-wrap,
[data-bs-theme="dark"] .tox .tox-view-wrap__slot-container {
    background-color: var(--bs-body-bg);
    display: flex;
    flex: 1;
    flex-direction: column;
    height: 100%
}

[data-bs-theme="dark"] .tox .tox-view {
    display: flex;
    flex: 1 1 auto;
    flex-direction: column;
    overflow: hidden
}

[data-bs-theme="dark"] .tox .tox-view__header {
    align-items: center;
    display: flex;
    font-size: 16px;
    justify-content: space-between;
    padding: 10px 10px 2px 10px;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-view__label {
    color: #fff;
    font-weight: 700;
    line-height: 24px;
    padding: 4px 16px;
    text-align: center;
    white-space: nowrap
}

[data-bs-theme="dark"] .tox .tox-view__label--normal {
    font-size: 16px
}

[data-bs-theme="dark"] .tox .tox-view__label--large {
    font-size: 20px
}

[data-bs-theme="dark"] .tox .tox-view--mobile.tox-view__header,
[data-bs-theme="dark"] .tox .tox-view--mobile.tox-view__toolbar {
    padding: 8px
}

[data-bs-theme="dark"] .tox .tox-view--scrolling {
    flex-wrap: nowrap;
    overflow-x: auto
}

[data-bs-theme="dark"] .tox .tox-view__toolbar {
    display: flex;
    flex-direction: row;
    gap: 8px;
    justify-content: space-between;
    overflow-x: auto;
    padding: 10px 10px 2px 10px
}

[data-bs-theme="dark"] .tox .tox-view__toolbar__group {
    display: flex;
    flex-direction: row;
    gap: 12px
}

[data-bs-theme="dark"] .tox .tox-view__header-end,
[data-bs-theme="dark"] .tox .tox-view__header-start {
    display: flex
}

[data-bs-theme="dark"] .tox .tox-view__pane {
    height: 100%;
    padding: 8px;
    position: relative;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-view__pane_panel {
    border: 1px solid #161f29;
    border-radius: 6px
}

[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-view__header .tox-view__header-end > *,
[data-bs-theme="dark"] .tox:not([dir=rtl]) .tox-view__header .tox-view__header-start > * {
    margin-left: 8px
}

[data-bs-theme="dark"] .tox[dir=rtl] .tox-view__header .tox-view__header-end > *,
[data-bs-theme="dark"] .tox[dir=rtl] .tox-view__header .tox-view__header-start > * {
    margin-right: 8px
}

[data-bs-theme="dark"] .tox .tox-well {
    border: 1px solid #161f29;
    border-radius: 6px;
    padding: 8px;
    width: 100%
}

[data-bs-theme="dark"] .tox .tox-well > :first-child {
    margin-top: 0
}

[data-bs-theme="dark"] .tox .tox-well > :last-child {
    margin-bottom: 0
}

[data-bs-theme="dark"] .tox .tox-well > :only-child {
    margin: 0
}

[data-bs-theme="dark"] .tox .tox-custom-editor {
    border: 1px solid #161f29;
    border-radius: 6px;
    display: flex;
    flex: 1;
    overflow: hidden;
    position: relative
}

[data-bs-theme="dark"] .tox .tox-dialog-loading::before {
    background-color: rgba(0, 0, 0, .5);
    content: "";
    height: 100%;
    position: absolute;
    width: 100%;
    z-index: 1000
}

[data-bs-theme="dark"] .tox .tox-tab {
    cursor: pointer
}

[data-bs-theme="dark"] .tox .tox-dialog__content-js {
    display: flex;
    flex: 1
}

[data-bs-theme="dark"] .tox .tox-dialog__body-content .tox-collection {
    display: flex;
    flex: 1
}

[data-bs-theme="dark"] .tox.tox-tinymce-aux .tox-toolbar__overflow {
    box-shadow: 0 0 0 1px rgba(255, 255, 255, .15)
}

[data-bs-theme="dark"] .mce-content-body {
    background-color: #000;
    color:#fff;
}
